eof

Function eof 

pub fn eof<E>() -> (Sender<E>, Receiver<E>)
Creates a byte stream that starts at EOF.

Data may still be added through the returned sender. The receiver yields that buffered data first and then completes.