Receiver

Struct Receiver 

pub struct Receiver<T> { /* private fields */ }
The receiving end of a channel which implements the Stream trait.

This is created by the channel function.

Implementations

Source

impl<T> Receiver<T>

pub fn sender(&self) -> Sender<T>

Creates an additional sender for this channel.

pub fn close(&self)

Closes the receiving half of a channel, without dropping it.

This prevents any further messages from being sent on the channel while still enabling the receiver to drain messages that are buffered.

pub fn is_closed(&self) -> bool

Returns whether this channel is closed.

pub async fn recv(&self) -> Option<T>

Waits for the next message.

Returns None once the channel is closed or every sender has been dropped, and every buffered message has been received.

pub fn poll_recv(&self, cx: &mut Context<'_>) -> Poll<Option<T>>

Polls for the next message.

Returns Ready(None) once the channel is closed or every sender has been dropped, and every buffered message has been received.