ClientError

Enum ClientError 

pub enum ClientError {
    Url(InvalidUrl),
    Connect(ConnectError),
    Send(Error),
    Request(EncodeError),
    Response(DecodeError),
    Http(HttpError),
    H2(OperationError),
    Timeout,
    Error(Rc<dyn StdError>),
}
Errors that can occur while sending a request or reading its response.

Variants



Url(InvalidUrl)

Invalid URL



Connect(ConnectError)

Failed to connect to host



Send(Error)

Error sending request



Request(EncodeError)

Error encoding request



Response(DecodeError)

Error parsing response



Http(HttpError)

Invalid request header



H2(OperationError)

Http2 error



Timeout

Response took too long



Error(Rc<dyn StdError>)

Other error, for example a request body or query serialization error