ServiceRequest

Struct ServiceRequest 

pub struct ServiceRequest { /* private fields */ }
HTTP request passed through client middleware before it is sent.

Implementations

Source

impl ServiceRequest

pub fn head(&mut self) -> &mut RequestHead

Returns mutable access to the request head.

pub fn headers(&mut self) -> &mut HeaderMap

Returns mutable access to the request’s extra headers.

Extra headers override headers with the same name in the request head when the request is encoded.

pub fn body(&mut self) -> &mut Body

Returns mutable access to the request body.

pub fn address(&mut self) -> &mut Option<SocketAddr>

Returns mutable access to the pre-resolved server address.