Connect

Struct Connect 

pub struct Connect<T> { /* private fields */ }
Request to resolve and connect to a remote address.

Implementations

Source

impl<T> Connect<T>
where T: Address,

pub fn new(req: T) -> Connect<T>

Creates a connection request and derives a port from the host when present.

pub fn with(req: T, addr: SocketAddr) -> Connect<T>

Creates a request with a pre-resolved socket address.

The connector skips DNS resolution for this request.

pub fn set_port(self, port: u16) -> Connect<T>

Sets the port used when Address::port() does not provide one.

This replaces the port parsed from a host:port host by new(), which is zero if the host has none.

pub fn set_addr(self, addr: Option<SocketAddr>) -> Connect<T>

Sets one pre-resolved socket address.

pub fn set_addrs<I>(self, addrs: I) -> Connect<T>
where I: IntoIterator<Item = SocketAddr>,

Sets multiple pre-resolved socket addresses.

pub fn host(&self) -> &str

Returns the request host name.

pub fn port(&self) -> u16

Returns the port from Address::port(), or the one parsed from the host or set by set_port().

pub fn addrs(&self) -> ConnectAddrsIter<'_>

Iterates over the request’s pre-resolved addresses.

pub fn take_addrs(&mut self) -> ConnectTakeAddrsIter

Removes and returns the request’s pre-resolved addresses.

pub fn get_ref(&self) -> &T

Returns the original address value.

pub fn map_addr<F, R>(self, f: F) -> Connect<R>
where F: FnOnce(T) -> R,

Maps the original address value while preserving port and resolved addresses.