Module error

Module error 

Modules

utils

Structs

Backtrace
Representation of a backtrace.
BacktraceRaw
Representation of a backtrace.
BacktraceResolver
Backtrace resolver.
Error
An error container.
ErrorInfo
Type-erased container holding error information.
ErrorMessage
ErrorMessageChained
ResultSignature
Helper type holding a result type and classification signature.
Success

Enums

ResultType
The type of the result.

Traits

AsError
ErrorDiagnostic
Provides diagnostic information for errors.
ErrorMapping
Helper trait for converting a value into a unified error-aware result type.
Retryable
The retry policy of the error.

Functions

fmt_diag
Formats a full diagnostic view of an error for logging and tracing.
fmt_diag_string
Formats a full diagnostic view of an error for logging and tracing.
fmt_diag_typ
Formats a full diagnostic view of an error for logging and tracing.
fmt_err
fmt_err_string
set_backtrace_start
with_service
Executes a future and ensures an error service is set.