pub fn module_path_prefix(prefix: &'static str, file_path: &str) -> ByteStringExpand description
Generates a Rust module path from the given source file path,
prepending prefix.
pub fn module_path_prefix(prefix: &'static str, file_path: &str) -> ByteStringGenerates a Rust module path from the given source file path,
prepending prefix.