ResponseBody

Enum ResponseBody 

pub enum ResponseBody<B> {
    Body(B),
    Other(Body),
}
Response body preserving either a concrete body type or a type-erased body.

Variants



Body(B)

The original concrete body.



Other(Body)

A type-erased body.

Implementations

Source

impl ResponseBody<Body>

pub fn into_body<B>(self) -> ResponseBody<B>

Converts a type-erased response body to another concrete response type.

Source

impl<B> ResponseBody<B>

pub fn new(body: B) -> ResponseBody<B>

Creates a response body from a concrete body value.

pub fn take_body(&mut self) -> ResponseBody<B>

Replaces this response body with Body::None and returns the original.

Source

impl<B> ResponseBody<B>
where B: MessageBody,

pub fn as_ref(&self) -> Option<&B>

Returns the concrete body, if this is ResponseBody::Body.