Encoder

Struct Encoder 

pub struct Encoder<B> { /* private fields */ }
Response body encoder.

Compresses a response body with the selected content encoding.

Implementations

Source

impl<B: MessageBody> Encoder<B>

pub fn response( encoding: ContentEncoding, head: &mut ResponseHead, body: ResponseBody<B>, ) -> ResponseBody<B>

Wrap a response body in an encoder for encoding.

On success the Content-Encoding header is set and chunked transfer-encoding is enabled. The body is returned unchanged if the encoding is not supported, is Identity or Auto, if the response already has a Content-Encoding header, if the status is 101 Switching Protocols or 204 No Content, or if the body is empty or its size is known to be below 1KiB.