Module error

Module error 

Http related errors

Structs

Canceled
Error returned from a Receiver when the corresponding Sender is dropped.
HttpError
A generic “error” for HTTP connections

Enums

BlockingError
Blocking operation execution error
ContentTypeError
A set of error that can occure during parsing content type
DecodeError
A set of errors that can occur during parsing HTTP streams
DispatchError
A set of errors that can occur during dispatching http requests
EncodeError
A set of errors that can occur during HTTP streams encoding
H2Error
A set of errors that can occur during dispatching http2 requests
PayloadError
A set of errors that can occur during payload parsing

Traits

ResponseError
Error that can be converted to Response