pub enum DecodeError {
Method,
Uri,
Version,
Header,
MaxHeaders,
TooLarge(usize),
StartLineTooLong(usize),
UnsupportedTransferCoding,
Incomplete,
Status,
InvalidInput(&'static str),
Utf8,
}Expand description
Errors that can occur while parsing HTTP streams.
Variants
Method
An invalid Method, such as GE.T.
Uri
An invalid Uri, such as exam ple.domain.
Version
An invalid HttpVersion, such as HTP/1.1
Header
An invalid Header.
MaxHeaders
The message contains more headers than the configured limit.
TooLarge(usize)
A message head is too large to be reasonable.
StartLineTooLong(usize)
A request or status line exceeds the configured limit.
UnsupportedTransferCoding
A request applies a transfer coding other than chunked.
Incomplete
A message reached EOF, but is not complete.
Status
An invalid Status, such as 1337 ELITE.
InvalidInput(&'static str)
An InvalidInput occurred while trying to parse incoming stream.
Utf8
Parsing a field as string failed