pub enum EncodeError {
UnsupportedVersion(Version),
UnexpectedEof,
UnknownLength,
}Expand description
Errors that can occur while encoding HTTP streams.
Variants
UnsupportedVersion(Version)
An invalid HttpVersion, such as HTP/1.1
UnexpectedEof
The encoded stream ended before the message was complete.
UnknownLength
A streaming request body has neither chunked coding nor Content-Length.