pub enum ServiceDisconnectReason {
Shutdown,
UpgradeHandled,
UpgradeFailed,
ExpectFailed,
PayloadDropped,
}Expand description
The reason the HTTP service is disconnecting.
Variants
Shutdown
The server is shutting down.
UpgradeHandled
The HTTP/1 dispatcher relinquished the connection after an upgrade was handed to the application or control service.
UpgradeFailed
Upgrade handling failed.
ExpectFailed
Expectation handling failed.
PayloadDropped
The application dropped an unread request payload, preventing reuse of the connection.