Expect

Struct Expect 

pub struct Expect(/* private fields */);
A request containing an Expect: 100-continue header.

Implementations

Source

impl Expect

pub fn get_ref(&self) -> &Request

Returns the HTTP request.

pub fn get_mut(&mut self) -> &mut Request

Returns mutable access to the HTTP request.

pub fn ack<F>(self) -> ControlAck<F>

Sends 100 Continue and passes the request to the application service.

pub fn fail<E: ResponseError, F>(self, err: E) -> ControlAck<F>

Rejects the expectation with the response generated from err.

pub fn fail_with<F>(self, res: Response) -> ControlAck<F>

Rejects the expectation with a custom response.