pub struct NewRequest(/* private fields */);Expand description
Notification that a complete request head has been received.
Implementations
Sourceimpl NewRequest
impl NewRequest
Sourcepub fn ack<F>(self) -> ControlAck<F>
pub fn ack<F>(self) -> ControlAck<F>
Accepts the request and continues with expectation handling, upgrade handling, or the application service as appropriate.
Sourcepub fn fail<E: ResponseError, F>(self, err: E) -> ControlAck<F>
pub fn fail<E: ResponseError, F>(self, err: E) -> ControlAck<F>
Rejects the request with the response generated from err.
Sourcepub fn fail_with<F>(self, res: Response) -> ControlAck<F>
pub fn fail_with<F>(self, res: Response) -> ControlAck<F>
Rejects the request with a custom response.