Upgrade

Struct Upgrade 

pub struct Upgrade<F> { /* private fields */ }
A request to upgrade the HTTP/1 connection.

Implementations

Source

impl<F: Filter> Upgrade<F>

pub fn io(&self) -> &Io<F>

Returns the connection I/O object.

pub fn get_ref(&self) -> &Request

Returns the upgrade request.

pub fn get_mut(&mut self) -> &mut Request

Returns mutable access to the upgrade request.

pub fn ack(self) -> ControlAck<F>

Passes the upgrade request to the application service.

The application can take ownership of the connection and codec through RequestHead::take_io.

pub fn handle(self) -> (ControlAck<F>, Io<F>, Request, Codec)

Takes ownership of the connection, request, and codec.

Returning this acknowledgement tells the dispatcher that the control service is responsible for the upgraded connection.

pub fn fail<E: ResponseError>(self, err: E) -> ControlAck<F>

Rejects the upgrade with the response generated from err.

pub fn fail_with(self, res: Response) -> ControlAck<F>

Rejects the upgrade with a custom response.