pub enum ProtocolError {
Decode(DecodeError),
Encode(EncodeError),
SlowRequestTimeout,
SlowPayloadTimeout,
ResponsePayload(Rc<dyn Error>),
}Expand description
Errors that can occur while dispatching HTTP/1 requests.
The default ResponseError implementation maps
header-count and message-head size failures to
431 Request Header Fields Too Large, other decoding failures to
400 Bad Request, request and payload timeouts to 408 Request Timeout,
and response encoding or body-stream failures to
500 Internal Server Error.
Variants
Decode(DecodeError)
HTTP request parsing failed.
Encode(EncodeError)
HTTP response encoding failed.
SlowRequestTimeout
The request head did not complete within the configured timeout.
SlowPayloadTimeout
The request payload did not complete within the configured timeout.
ResponsePayload(Rc<dyn Error>)
The response body stream returned an error.