Control

Enum Control 

pub enum Control<E> {
    Disconnect(Reason<E>),
    Expect(Expect),
}
Connection control event.

Variants



Disconnect(Reason<E>)

The connection is preparing to disconnect.



Expect(Expect)

A request contains Expect: 100-continue.

The server does not emit this event, it is created by the application layer with Control::expect before the request is processed.

Implementations



impl<E> Control<E>

pub fn expect( stream: StreamRef, pseudo: PseudoHeaders, headers: HeaderMap, ) -> Control<E>

Creates a new Control message for a request with Expect: 100-continue.

pub fn ack(self) -> ControlAck

Returns the default acknowledgment for this event.