Payload

Struct Payload 

pub struct Payload { /* private fields */ }
Buffered HTTP/2 payload stream.

Use Payload::read to receive the next chunk asynchronously, or consume the payload through its Stream implementation. Waiting tasks are woken when data, end-of-stream, or an error becomes available.

This type is not thread-safe and can also be used as a Response body stream.

Implementations

Source

impl Payload

pub fn create(cap: Capacity) -> (PayloadSender, Payload)

Create payload stream.

This method construct two objects responsible for bytes stream generation.

  • PayloadSender - Sender side of the stream

  • Payload - Receiver side of the stream

pub async fn read(&self) -> Option<Result<Bytes, PayloadError>>

Receives the next payload chunk.

Returns None after the complete payload has been received.

pub fn poll_read( &self, cx: &mut Context<'_>, ) -> Poll<Option<Result<Bytes, PayloadError>>>

Polls for the next payload chunk.

pub fn trailers(&self) -> Option<HeaderMap>

Returns the trailer fields received at the end of the payload.

Trailers are available after the payload is complete, None is returned if the payload is not complete or has no trailers.