Request

Struct Request 

pub struct Request { /* private fields */ }
An HTTP request.

Implementations

Source

impl Request

pub fn new() -> Request

Creates an empty request.

Source

impl Request

pub fn with_payload(payload: Payload) -> Request

Creates a request with the supplied payload.

pub fn head(&self) -> &RequestHead

Returns the request head.

pub fn uri(&self) -> &Url

Returns the request URI.

pub fn uri_mut(&mut self) -> &mut Url

Returns mutable access to the request URI.

pub fn method(&self) -> &Method

Returns the request method.

pub fn version(&self) -> Version

Returns the HTTP version.

pub fn path(&self) -> &str

Returns the path component of the request URI.

pub fn headers(&self) -> &HeaderMap

Returns the request headers.

pub fn headers_mut(&mut self) -> &mut HeaderMap

Returns mutable access to the request headers.

pub fn upgrade(&self) -> bool

Returns whether this is an upgrade or CONNECT request.

pub fn io(&self) -> Option<&IoRef>

Returns the I/O object for the current connection, when available.

pub fn peer_addr(&self) -> Option<SocketAddr>

Returns the peer socket address.

Peer address is actual socket address, if proxy is used in front of ntex http server, then peer address would be address of this proxy.

pub fn payload(&mut self) -> &mut Payload

Returns mutable access to the request payload.

pub fn take_payload(&mut self) -> Payload

Takes the request payload, leaving an empty payload behind.

pub fn replace_payload(&mut self, payload: Payload) -> Payload

Replaces the request payload and returns the previous value.

pub fn extensions(&self) -> Ref<'_, Extensions>

Returns the request extensions.

pub fn extensions_mut(&self) -> RefMut<'_, Extensions>

Returns mutable access to the request extensions.