Response

Struct Response 

pub struct Response<B = Body> { /* private fields */ }
An HTTP response.

Implementations

Source

impl Response

pub fn Ok() -> ResponseBuilder

pub fn Created() -> ResponseBuilder

pub fn Accepted() -> ResponseBuilder

pub fn NonAuthoritativeInformation() -> ResponseBuilder

pub fn NoContent() -> ResponseBuilder

pub fn ResetContent() -> ResponseBuilder

pub fn PartialContent() -> ResponseBuilder

pub fn MultiStatus() -> ResponseBuilder

pub fn AlreadyReported() -> ResponseBuilder

pub fn MultipleChoices() -> ResponseBuilder

pub fn MovedPermanently() -> ResponseBuilder

pub fn Found() -> ResponseBuilder

pub fn SeeOther() -> ResponseBuilder

pub fn NotModified() -> ResponseBuilder

pub fn UseProxy() -> ResponseBuilder

pub fn TemporaryRedirect() -> ResponseBuilder

pub fn PermanentRedirect() -> ResponseBuilder

pub fn BadRequest() -> ResponseBuilder

pub fn NotFound() -> ResponseBuilder

pub fn Unauthorized() -> ResponseBuilder

pub fn PaymentRequired() -> ResponseBuilder

pub fn Forbidden() -> ResponseBuilder

pub fn MethodNotAllowed() -> ResponseBuilder

pub fn NotAcceptable() -> ResponseBuilder

pub fn ProxyAuthenticationRequired() -> ResponseBuilder

pub fn RequestTimeout() -> ResponseBuilder

pub fn Conflict() -> ResponseBuilder

pub fn Gone() -> ResponseBuilder

pub fn LengthRequired() -> ResponseBuilder

pub fn PreconditionFailed() -> ResponseBuilder

pub fn PreconditionRequired() -> ResponseBuilder

pub fn PayloadTooLarge() -> ResponseBuilder

pub fn UriTooLong() -> ResponseBuilder

pub fn UnsupportedMediaType() -> ResponseBuilder

pub fn RangeNotSatisfiable() -> ResponseBuilder

pub fn ExpectationFailed() -> ResponseBuilder

pub fn MisdirectedRequest() -> ResponseBuilder

pub fn UnprocessableEntity() -> ResponseBuilder

pub fn Locaked() -> ResponseBuilder

pub fn FailedDependency() -> ResponseBuilder

pub fn TooEarly() -> ResponseBuilder

pub fn UpgradeRequired() -> ResponseBuilder

pub fn TooManyRequests() -> ResponseBuilder

pub fn RequestHeaderFieldsTooLarge() -> ResponseBuilder

pub fn InternalServerError() -> ResponseBuilder

pub fn NotImplemented() -> ResponseBuilder

pub fn BadGateway() -> ResponseBuilder

pub fn ServiceUnavailable() -> ResponseBuilder

pub fn GatewayTimeout() -> ResponseBuilder

pub fn VersionNotSupported() -> ResponseBuilder

pub fn VariantAlsoNegotiates() -> ResponseBuilder

pub fn InsufficientStorage() -> ResponseBuilder

pub fn LoopDetected() -> ResponseBuilder

Source

impl Response<Body>

pub fn builder(status: StatusCode) -> ResponseBuilder

Creates a response builder with the given status.

pub fn builder_from<T: Into<ResponseBuilder>>(source: T) -> ResponseBuilder

Creates a response builder from another compatible value.

pub fn new(status: StatusCode) -> Response

Constructs a response.

pub fn render_with<B: Display>(status: StatusCode, body: &B) -> Response

Renders a displayable value as a plain-text response body.

pub fn into_body<B>(self) -> Response<B>

Converts the default body into a custom response body type.

Source

impl<B> Response<B>

pub fn with_body(status: StatusCode, body: B) -> Response<B>

Creates a response with the given status and body.

pub fn head(&self) -> &ResponseHead

Returns the response head.

pub fn head_mut(&mut self) -> &mut ResponseHead

Returns mutable access to the response head.

pub fn status(&self) -> StatusCode

Returns the response status code.

pub fn status_mut(&mut self) -> &mut StatusCode

Returns mutable access to the response status code.

pub fn headers(&self) -> &HeaderMap

Returns the response headers.

pub fn headers_mut(&mut self) -> &mut HeaderMap

Returns mutable access to the response headers.

pub fn cookies(&self) -> CookieIter<'_>

Get an iterator for the cookies set by this response.

Add a cookie to this response.

Remove all cookies with the given name from this response.

Returns the number of cookies removed.

pub fn upgrade(&self) -> bool

Connection upgrade status.

pub fn keep_alive(&self) -> bool

Keep-alive status for this connection.

pub fn extensions(&self) -> Ref<'_, Extensions>

Returns the response extensions.

pub fn extensions_mut(&self) -> RefMut<'_, Extensions>

Returns mutable access to the response extensions.

pub fn body(&self) -> &ResponseBody<B>

Returns the response body.

pub fn set_body<B2>(self, body: B2) -> Response<B2>

Replaces the response body with a different body type.

pub fn into_parts(self) -> (Response<()>, ResponseBody<B>)

Splits the response into its metadata and body.

pub fn drop_body(self) -> Response<()>

Drops the response body while preserving the response head.

pub fn map_body<F, B2>(self, f: F) -> Response<B2>
where F: FnOnce(&mut ResponseHead, ResponseBody<B>) -> ResponseBody<B2>,

Transforms the response body and allows its metadata to be updated.

pub fn take_body(&mut self) -> ResponseBody<B>

Takes the response body, leaving an empty body behind.

Source

impl Response<Body>

pub fn take(&mut self) -> Response

Takes the response body while preserving its metadata.

The returned response contains the original body and a copy of the response head without its extensions. This response is left with an empty body, both responses can be modified independently.