pub struct FrameReadRate {
pub timeout: Seconds,
pub max_timeout: Seconds,
pub rate: u32,
}Expand description
Minimum read rate required while decoding one frame.
Fields
timeout: SecondsInitial read timeout.
max_timeout: SecondsMaximum cumulative timeout for the frame.
rate: u32Byte-progress threshold that must be exceeded to extend the deadline.
Progress must be strictly greater than this value for another timeout
period to be granted.