TimerHandle

Struct TimerHandle 

pub struct TimerHandle(/* private fields */);
Handle to an I/O dispatcher timer.

Handles represent second-granularity deadlines managed by the current thread’s I/O manager, a timer started with a t seconds timeout expires after at least t and less than t + 1 seconds. The timer clock starts a new second when a timer starts while no other timers are pending, such a timer expires after t seconds. A handle becomes stale after its timer is stopped or replaced and must not be used as an independent cancellation token.

Implementations

Source

impl TimerHandle

pub const ZERO: TimerHandle

A handle that does not refer to an active timer.

pub fn is_set(&self) -> bool

Returns true if this handle refers to a timer deadline.

This does not guarantee that the timer is still registered or has not already elapsed.

pub fn remains(&self) -> Seconds

Returns the whole seconds remaining until this handle’s deadline.

Returns zero if the deadline has elapsed. The remaining time is measured from the cached now(), which lags the clock, and is rounded up.

pub fn instant(&self) -> Instant

Returns the instant represented by this handle.

The instant is based on the current thread’s I/O timer clock. For ZERO, this is the clock’s base instant.