Path

Struct Path 

pub struct Path<T> { /* private fields */ }
Resource path match information

Wraps a path source and stores the values of dynamic segments matched by a Router.

Implementations

Source

impl<T> Path<T>
where T: ResourcePath,

pub fn new(resource: T) -> Path<T>

Creates a new path state for the path source.

pub fn get_ref(&self) -> &T

Get reference to inner path instance

pub fn get_mut(&mut self) -> &mut T

Get mutable reference to inner path instance

pub fn into_inner(self) -> T

Consume the path state and return the inner path instance

pub fn path(&self) -> &str

Path that is not matched yet, e.g. the rest of the path after a prefix resource matched.

Unlike get_ref().path(), which is the full path, it excludes the skipped part of the path.

pub fn set(&mut self, resource: T)

Set new path source and reset state

pub fn reset(&mut self)

Reset skipped length and matched segments

pub fn skip(&mut self, n: u32)

Skip first n bytes in path, matching starts after them

The skipped length is limited to the path length.

pub fn is_empty(&self) -> bool

Check if there are any matched segments

pub fn len(&self) -> usize

Number of matched segments

pub fn get(&self, key: &str) -> Option<&str>

Get matched segment by name without type conversion

If no segment is named tail, the tail key returns the unprocessed part of the path, see path().

pub fn iter(&self) -> PathIter<'_, T> ⓘ

Iterator over matched segments as (name, value) pairs, in pattern order

pub fn load<'de, U>(&'de self) -> Result<U, Error>
where U: Deserialize<'de>,

Try to deserialize matched segments to a specified type U

See PathDeserializer.