ResourceDef

Struct ResourceDef 

pub struct ResourceDef { /* private fields */ }
ResourceDef describes an entry in resources table

A resource definition can have several path patterns, a path matches the resource if it matches any of them. The first pattern is the primary one, it is used by pattern() and for building resource paths.

Implementations

Source

impl ResourceDef

pub fn new<T>(path: T) -> ResourceDef
where T: IntoPattern,

Parse path patterns and create new ResourceDef instance.

Path segments are separated by /, a leading / is optional. Static segments could be case insensitive.

Panics if path pattern is malformed.

pub fn prefix<T>(path: T) -> ResourceDef
where T: IntoPattern,

Parse path patterns and create new prefix ResourceDef instance.

A prefix resource matches paths that start with one of its patterns.

Panics if path pattern is malformed.

pub fn root_prefix<T>(path: T) -> ResourceDef
where T: IntoPattern,

Parse path patterns and create new prefix ResourceDef instance.

Same as prefix(), but inserts / to the start of the patterns that do not have it.

Panics if path pattern is malformed.

pub fn id(&self) -> u16

Resource id, 0 by default

A matched resource is reported with this id, see ResourceId.

pub fn set_id(&mut self, id: u16)

Set resource id

pub fn is_prefix(&self) -> bool

Check if the resource is a prefix resource, see prefix()

pub fn name(&self) -> &str

Resource name, empty by default

pub fn set_name<N>(&mut self, name: N)
where N: Into<String>,

Set resource name

pub fn pattern(&self) -> &str

Primary path pattern of the resource, the first one

pub fn patterns(&self) -> &[String]

All path patterns of the resource

pub fn build_path<U, I>(&self, path: &mut String, elements: U) -> bool
where U: IntoIterator<Item = I>, I: AsRef<str>,

Build resource path from elements, using the primary pattern.

Elements are used for dynamic segments in pattern order, an iterator can be passed by &mut to continue using it afterwards. The path is appended to path. Returns false if there are not enough elements, path is left unchanged then.

pub fn build_path_named<K, V, S>( &self, path: &mut String, elements: &HashMap<K, V, S>, ) -> bool
where K: Borrow<str> + Eq + Hash, V: AsRef<str>, S: BuildHasher,

Build resource path from named elements, using the primary pattern.

The path is appended to path. Returns false if an element is missing, path is left unchanged then.