Router

Struct Router 

pub struct Router<T, U = ()> { /* private fields */ }
Resource router.

Maps paths to values of type T. Each resource can also have an optional value of type U used by the recognize_*checked methods. Resources are matched in registration order, the first matching resource wins.

Implementations

Source

impl<T, U> Router<T, U>

pub fn builder() -> RouterBuilder<T, U>

Creates a router builder.

pub fn recognize<R, P>(&self, resource: &mut R) -> Option<(&T, ResourceId)>
where R: Resource<P>, P: ResourcePath,

Finds the first resource that matches the path.

On a match, the values of dynamic segments are stored in resource, and a prefix match skips the matched part of the path.

pub fn recognize_mut<R, P>( &mut self, resource: &mut R, ) -> Option<(&mut T, ResourceId)>
where R: Resource<P>, P: ResourcePath,

Same as recognize(), returns a mutable reference.

pub fn recognize_checked<R, P, F>( &self, resource: &mut R, check: F, ) -> Option<(&T, ResourceId)>
where F: Fn(&R, Option<&U>) -> bool, R: Resource<P>, P: ResourcePath,

Finds the first resource that matches the path and passes check.

check is called for each matching resource with the resource and the resource’s optional value of type U.

pub fn recognize_checked_mut<R, P, F>( &mut self, resource: &mut R, check: F, ) -> Option<(&mut T, ResourceId)>
where F: Fn(&R, Option<&U>) -> bool, R: Resource<P>, P: ResourcePath,

Same as recognize_checked(), returns a mutable reference.