RouterBuilder

Struct RouterBuilder 

pub struct RouterBuilder<T, U = ()> { /* private fields */ }
Router builder, see Router::builder().

The registration methods return the registered RouterEntry, it can be used to set the resource id or name, or the value used by the recognize_*checked methods.

Implementations

Source

impl<T, U> RouterBuilder<T, U>

pub fn case_insensitive(&mut self)

Make router case insensitive. Only static segments could be case insensitive.

By default router is case sensitive.

pub fn path<P>(&mut self, path: P, resource: T) -> &mut RouterEntry<T, U>
where P: IntoPattern,

Register resource for specified path patterns, see ResourceDef::new().

pub fn prefix<P>(&mut self, prefix: P, resource: T) -> &mut RouterEntry<T, U>
where P: IntoPattern,

Register resource for specified path prefix patterns, see ResourceDef::prefix().

pub fn resource( &mut self, rdef: ResourceDef, resource: T, ) -> &mut RouterEntry<T, U>

Register resource for ResourceDef

pub fn build(self) -> Router<T, U>

Finish configuration and create router instance.