RouterEntry

Struct RouterEntry 

pub struct RouterEntry<T, U = ()> { /* private fields */ }
Registered resource, see RouterBuilder.

Holds the resource definition, the value and the optional value passed to the check function of the recognize_*checked methods.

Implementations

Source

impl<T, U> RouterEntry<T, U>

pub fn resource(&self) -> &ResourceDef

Resource definition

pub fn resource_mut(&mut self) -> &mut ResourceDef

Mutable reference to the resource definition

pub fn value(&self) -> &T

Value returned for matched resource

pub fn value_mut(&mut self) -> &mut T

Mutable reference to the value returned for matched resource

pub fn check_value(&self) -> Option<&U>

Value passed to the check function of the recognize_*checked methods

pub fn set_check_value<V>(&mut self, value: V) -> &mut RouterEntry<T, U>
where V: Into<Option<U>>,

Set value passed to the check function of the recognize_*checked methods

pub fn set_id(&mut self, id: u16) -> &mut RouterEntry<T, U>

Set resource id, see ResourceDef::set_id()

pub fn set_name<N>(&mut self, name: N) -> &mut RouterEntry<T, U>
where N: Into<String>,

Set resource name, see ResourceDef::set_name()