IntoPattern

Trait IntoPattern 

pub trait IntoPattern {
    // Required method
    fn patterns(&self) -> Vec<String>;
}
Helper trait for type that could be converted to path patterns.

Implemented for strings, and for vectors and arrays of strings for resources with several patterns.

Required Methods

fn patterns(&self) -> Vec<String>

Path patterns.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoPattern for &String

Source

impl IntoPattern for &str

Source

impl IntoPattern for String

Source

impl<T, const N: usize> IntoPattern for [T; N]
where T: AsRef<str>,

Source

impl<T> IntoPattern for Vec<T>
where T: AsRef<str>,

Implementors