Module rt

Module rt 

A runtime implementation that runs everything on the current thread.

Modules

channel
A one-shot, futures-aware channel.
connect
Tcp connector service
polling
rt_default
rt_tokio
tokio
uring

Macros

syscall
Helper macro to execute a system call

Structs

Arbiter
Arbiters provide an asynchronous execution environment for actors, functions and futures.
BlockingError
An error that may be emitted when all worker threads are busy.
BlockingResult
Builder
Builder struct for a ntex runtime.
DefaultRuntime
Handle
Handle to the runtime.
Id
System id
JoinError
JoinHandle
PingRecord
Runtime
The async runtime for ntex
RuntimeBuilder
Builder for Runtime.
System
System is a runtime manager
SystemRunner
Helper object that runs System’s event loop
ThreadPool
A thread pool for executing blocking operations.

Enums

DriverType
PollResult

Traits

Driver
Notify
Reactor
Runner

Functions

from_tcp_stream
Convert std TcpStream to TcpStream
from_unix_stream
Convert std UnixStream to UnixStream
get_item
Get a reference to a type previously inserted on this runtime’s storage
set_item
Set item to current runtime’s storage
spawn
Spawn a future on the current thread.
spawn_blocking
Spawns a blocking task in a new thread, and wait for it.
task_callbacks
Safety
task_opt_callbacks
Safety
tcp_connect
Opens a TCP connection to a remote host.
unix_connect
Opens a unix stream connection.

Type Aliases

BlockFuture