pub struct Connect<T> { /* private fields */ }Expand description
Connect request
Implementations
Sourceimpl<T> Connect<T>where
T: Address,
impl<T> Connect<T>where
T: Address,
Sourcepub fn new(req: T) -> Connect<T>
pub fn new(req: T) -> Connect<T>
Create Connect instance by spliting the string by ‘:’ and convert the second part to u16
Sourcepub fn with(req: T, addr: SocketAddr) -> Connect<T>
pub fn with(req: T, addr: SocketAddr) -> Connect<T>
Create new Connect instance from host and address. Connector skips name resolution stage for such connect messages.
Sourcepub fn set_port(self, port: u16) -> Connect<T>
pub fn set_port(self, port: u16) -> Connect<T>
Use port if address does not provide one.
By default it set to 0
Sourcepub fn set_addr(self, addr: Option<SocketAddr>) -> Connect<T>
pub fn set_addr(self, addr: Option<SocketAddr>) -> Connect<T>
Use address.
Sourcepub fn set_addrs<I>(self, addrs: I) -> Connect<T>where
I: IntoIterator<Item = SocketAddr>,
pub fn set_addrs<I>(self, addrs: I) -> Connect<T>where
I: IntoIterator<Item = SocketAddr>,
Use addresses.
Sourcepub fn take_addrs(&mut self) -> ConnectTakeAddrsIter
pub fn take_addrs(&mut self) -> ConnectTakeAddrsIter
Takes preresolved addresses of the request.