pub fn set_item<T>(item: T)where
T: 'static,Expand description
Inserts a value into the current arbiter’s thread-local storage.
If the storage has already been destroyed because the thread is exiting, the value is dropped.
pub fn set_item<T>(item: T)where
T: 'static,Inserts a value into the current arbiter’s thread-local storage.
If the storage has already been destroyed because the thread is exiting, the value is dropped.