with_reactor

Function with_reactor 

pub fn with_reactor<R, F>(r: &Box<dyn Reactor>, f: F) -> R
where F: FnOnce() -> R,
Sets the current reactor and runs the provided closure.

Panics

Panics if a reactor is already active on the current thread.