spawn

Function spawn 

pub fn spawn<F>(f: F) -> JoinHandle<<F as Future>::Output> ⓘ
where F: Future + 'static,
Spawn a future on the current thread.

This does not create a new Arbiter or Arbiter address, it is simply a helper for spawning futures on the current thread.

Panics

This function panics if ntex system is not running.