TestServerBuilder

Struct TestServerBuilder 

pub struct TestServerBuilder<Cfg, F, Sf, I> { /* private fields */ }
Builder for a single-worker test server.

The server listens on an ephemeral 127.0.0.1 port and runs in a separate thread with its own runtime.

Implementations

Source

impl<F, S, I> TestServerBuilder<NoConfig, F, S, I>
where F: AsyncFn() -> I + Send + Clone + 'static, I: IntoService<S, (), Io> + 'static, S: Service<(), Io> + 'static,

pub fn new(factory: F) -> TestServerBuilder<NoConfig, F, S, I>

Creates a test server builder for the specified service factory.

Source

impl<Cfg, F, S, I> TestServerBuilder<Cfg, F, S, I>
where F: AsyncFn() -> I + Send + Clone + 'static, I: IntoService<S, <Cfg as ServerAppConfig>::State, Io> + 'static, S: Service<<Cfg as ServerAppConfig>::State, Io> + 'static, Cfg: ServerAppConfig + 'static,

pub fn with(cfg: Cfg, factory: F) -> TestServerBuilder<Cfg, F, S, I>

Creates a test server builder with application configuration.

pub fn config<T>(self, cfg: T) -> TestServerBuilder<Cfg, F, S, I>
where T: Into<SharedCfg>,

Sets the I/O configuration for accepted server connections.

pub fn client_config<T>(self, cfg: T) -> TestServerBuilder<Cfg, F, S, I>
where T: Into<SharedCfg>,

Sets the I/O configuration used by TestServer::connect.

pub fn start(self) -> TestServer

Starts the test server and returns its controller.