pub struct Cfg<T>(/* private fields */)
where
T: Configuration;Expand description
A typed handle to a value in a SharedCfg.
Implementations
Sourceimpl<T> Cfg<T>where
T: Configuration,
impl<T> Cfg<T>where
T: Configuration,
Returns a handle to the complete shared configuration.
Returns another typed value from the same shared configuration.