pub fn fn_service_st<F, St, Req, Res, Err>(
f: F,
) -> FnServiceSt<F, St, Req, Res, Err>Expand description
Converts a state-aware asynchronous function into a Service.
This service accesses the pipeline state via the first &St parameter.
pub fn fn_service_st<F, St, Req, Res, Err>(
f: F,
) -> FnServiceSt<F, St, Req, Res, Err>Converts a state-aware asynchronous function into a Service.
This service accesses the pipeline state via the first &St parameter.