map_state_factory

Function map_state_factory 

pub fn map_state_factory<Sf, St, Req>(
    st: St,
    sf: impl IntoServiceFactory<Sf, St, Req>,
) -> MapStateFactory<Sf, St>
where Sf: ServiceFactory<St, Req>, St: Clone,
Wraps a service factory with a fixed state value.

The fixed state is used both to create services and to process their calls.