PipelineStateBinding

Struct PipelineStateBinding 

pub struct PipelineStateBinding<St, Req, Res, Err> { /* private fields */ }
An independently registered handle to a PipelineState.

Implementations

Source

impl<St, Req, Res, Err> PipelineStateBinding<St, Req, Res, Err>
where St: 'static, Req: 'static, Res: 'static, Err: 'static,

pub async fn call(&self, req: Req, st: &St) -> Result<Res, Err>

Waits for readiness, then calls the service with st.

The readiness check is skipped if the last pipeline readiness check succeeded and no call has started since.