RequestState

Trait RequestState 

pub trait RequestState<Req> {
    type State: 'static;

    // Required method
    fn unpack(self) -> (Self::State, Req);
}
A request that carries state for a service call.

Required Associated Types

type State: 'static

State extracted from the request.

Required Methods

fn unpack(self) -> (Self::State, Req)

Splits this value into its state and request components.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Req, St> RequestState<Req> for (St, Req)
where St: 'static,

Implementors

Source

impl RequestState<IoBoxed> for IoBoxed

Source

impl<F, St> RequestState<IoBoxed> for State<St, Io<F>>
where F: Filter, St: 'static,

Source

type State = St

Source

impl<F> RequestState<Io<F>> for Io<F>

Source

impl<F> RequestState<IoBoxed> for Io<F>
where F: Filter,

Source

impl<Req, St> RequestState<Req> for State<St, Req>
where St: 'static,

Source

type State = St