Deadline

Struct Deadline 

pub struct Deadline { /* private fields */ }
Future returned by deadline.

Examples

Wait 100ms and print “100 ms have elapsed”.

use ntex::time::{deadline, Millis};

#[ntex::main]
async fn main() {
    deadline(Millis(100)).await;
    println!("100 ms have elapsed");
}

Implementations

Source

impl Deadline

pub fn new(duration: Millis) -> Deadline ⓘ

Creates a new deadline future.

A zero duration creates a deadline that never completes.

pub async fn wait(&self)

Waits until this deadline has elapsed.

pub fn reset<T>(&mut self, millis: T)
where T: Into<Millis>,

Resets the Deadline instance to a new deadline.

Calling this function allows changing the instant at which the Deadline future completes without having to create new associated state.

This function can be called both before and after the future has completed.

pub fn is_elapsed(&self) -> bool

Returns true if Deadline has elapsed.

A disabled zero-duration deadline is reported as elapsed here even though polling it remains pending. Use this method to determine whether there is an active future deadline to wait for.

pub fn poll_elapsed(&self, cx: &mut Context<'_>) -> Poll<()>

Polls until this deadline has elapsed.

A zero-duration deadline remains pending until it is reset.