max_concurrent_ssl_accept

Function max_concurrent_ssl_accept 

pub fn max_concurrent_ssl_accept(num: usize)
Sets the maximum per-worker concurrent ssl connection establish process.

All listeners will stop accepting connections when this limit is reached. It can be used to limit the global SSL CPU usage.

By default max connections is set to a 256.