pub struct SslConnectorService2<S> { /* private fields */ }Trait Implementations
Sourceimpl<S> Clone for SslConnectorService2<S>where
S: Clone,
impl<S> Clone for SslConnectorService2<S>where
S: Clone,
Sourcefn clone(&self) -> SslConnectorService2<S>
fn clone(&self) -> SslConnectorService2<S>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<S> Debug for SslConnectorService2<S>where
S: Debug,
impl<S> Debug for SslConnectorService2<S>where
S: Debug,
Sourceimpl<A, S> Service<Connect<A>> for SslConnectorService2<S>
impl<A, S> Service<Connect<A>> for SslConnectorService2<S>
Sourcetype Error = Error<ConnectError>
type Error = Error<ConnectError>
Errors produced by the service when polling readiness or executing call.
Sourceasync fn ready(
&self,
ctx: ServiceCtx<'_, SslConnectorService2<S>>,
) -> Result<(), <SslConnectorService2<S> as Service<Connect<A>>>::Error>
async fn ready( &self, ctx: ServiceCtx<'_, SslConnectorService2<S>>, ) -> Result<(), <SslConnectorService2<S> as Service<Connect<A>>>::Error>
Returns when the service is ready to process requests. Read more
Sourcefn poll(
&self,
cx: &mut Context<'_>,
) -> Result<(), <SslConnectorService2<S> as Service<Connect<A>>>::Error>
fn poll( &self, cx: &mut Context<'_>, ) -> Result<(), <SslConnectorService2<S> as Service<Connect<A>>>::Error>
Polls the service from the current async task. Read more
Sourceasync fn call(
&self,
message: Connect<A>,
ctx: ServiceCtx<'_, SslConnectorService2<S>>,
) -> Result<<SslConnectorService2<S> as Service<Connect<A>>>::Response, <SslConnectorService2<S> as Service<Connect<A>>>::Error>
async fn call( &self, message: Connect<A>, ctx: ServiceCtx<'_, SslConnectorService2<S>>, ) -> Result<<SslConnectorService2<S> as Service<Connect<A>>>::Response, <SslConnectorService2<S> as Service<Connect<A>>>::Error>
Processes a request and returns the response asynchronously. Read more