Buffer

Struct Buffer 

pub struct Buffer<St, Req, Res, Err>
where St: Clone,
{ /* private fields */ }
Middleware that buffers requests while the wrapped service is not ready.

See BufferService for how buffered requests are released.

The default buffer capacity is 16 requests.

Implementations

Source

impl<St, Req, Res, Err> Buffer<St, Req, Res, Err>
where St: Clone,

pub fn buf_size(self, size: usize) -> Buffer<St, Req, Res, Err>

Sets the maximum number of buffered requests.

The default capacity is 16.

pub fn cancel_on_shutdown(self) -> Buffer<St, Req, Res, Err>

Cancel all buffered requests on shutdown.

By default, buffered requests are released during service shutdown.