Either

Enum Either 

pub enum Either<A, B> {
    Left(A),
    Right(B),
}
A value of one of two types.

Either is a Future when both variants are futures with the same output, and a Service when both variants are services with the same request, response, and error types.

Variants



Left(A)

First branch of the type



Right(B)

Second branch of the type

Implementations

Source

impl<A, B> Either<A, B>

pub fn is_left(&self) -> bool

Returns true if the value is the Left variant.

pub fn is_right(&self) -> bool

Returns true if the value is the Right variant.

pub fn left(self) -> Option<A>

Converts the left side of Either<A, B> to an Option<A>.

pub fn right(self) -> Option<B>

Converts the right side of Either<A, B> to an Option<B>.

pub fn as_ref(&self) -> Either<&A, &B> ⓘ

Converts &Either<A, B> to Either<&A, &B>.

pub fn as_mut(&mut self) -> Either<&mut A, &mut B> ⓘ

Converts &mut Either<A, B> to Either<&mut A, &mut B>.

Source

impl<T> Either<T, T>

pub fn into_inner(self) -> T

Extracts the value of an Either over two equal types.