pub async fn join_all<I>(
i: I,
) -> Vec<<<I as IntoIterator>::Item as Future>::Output>Expand description
Creates a future which represents a collection of the outputs of the futures given.
pub async fn join_all<I>(
i: I,
) -> Vec<<<I as IntoIterator>::Item as Future>::Output>Creates a future which represents a collection of the outputs of the futures given.