pub struct KeepAliveService<F, E>where
F: Fn() -> E,{ /* private fields */ }Expand description
A service that fails readiness once it has been idle too long.
See KeepAlive for details.
Implementations
Sourceimpl<F, E> KeepAliveService<F, E>where
F: Fn() -> E,
impl<F, E> KeepAliveService<F, E>where
F: Fn() -> E,
Sourcepub fn new(dur: Millis, f: F) -> KeepAliveService<F, E>
pub fn new(dur: Millis, f: F) -> KeepAliveService<F, E>
Creates a keep-alive service with the maximum idle time dur.
f creates the error returned once the service has been idle longer
than dur.