pub struct VariantService2<V1, V2, V1R, V2R> { /* private fields */ }Trait Implementations
Sourceimpl<V1, V2, V1R, V2R> Clone for VariantService2<V1, V2, V1R, V2R>
impl<V1, V2, V1R, V2R> Clone for VariantService2<V1, V2, V1R, V2R>
Sourcefn clone(&self) -> VariantService2<V1, V2, V1R, V2R>
fn clone(&self) -> VariantService2<V1, V2, V1R, V2R>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<V1, V2, V1R, V2R> Debug for VariantService2<V1, V2, V1R, V2R>
impl<V1, V2, V1R, V2R> Debug for VariantService2<V1, V2, V1R, V2R>
Sourceimpl<V1, V2, V1R, V2R> Service<Variant2<V1R, V2R>> for VariantService2<V1, V2, V1R, V2R>
impl<V1, V2, V1R, V2R> Service<Variant2<V1R, V2R>> for VariantService2<V1, V2, V1R, V2R>
Sourcetype Error = <V1 as Service<V1R>>::Error
type Error = <V1 as Service<V1R>>::Error
Errors produced by the service when polling readiness or executing call.
Sourceasync fn ready(
&self,
ctx: ServiceCtx<'_, VariantService2<V1, V2, V1R, V2R>>,
) -> Result<(), <VariantService2<V1, V2, V1R, V2R> as Service<Variant2<V1R, V2R>>>::Error>
async fn ready( &self, ctx: ServiceCtx<'_, VariantService2<V1, V2, V1R, V2R>>, ) -> Result<(), <VariantService2<V1, V2, V1R, V2R> as Service<Variant2<V1R, V2R>>>::Error>
Returns when the service is able to process requests. Read more
Sourcefn poll(
&self,
cx: &mut Context<'_>,
) -> Result<(), <VariantService2<V1, V2, V1R, V2R> as Service<Variant2<V1R, V2R>>>::Error>
fn poll( &self, cx: &mut Context<'_>, ) -> Result<(), <VariantService2<V1, V2, V1R, V2R> as Service<Variant2<V1R, V2R>>>::Error>
Polls service from the current task. Read more
Sourceasync fn call(
&self,
req: Variant2<V1R, V2R>,
ctx: ServiceCtx<'_, VariantService2<V1, V2, V1R, V2R>>,
) -> Result<<VariantService2<V1, V2, V1R, V2R> as Service<Variant2<V1R, V2R>>>::Response, <VariantService2<V1, V2, V1R, V2R> as Service<Variant2<V1R, V2R>>>::Error>
async fn call( &self, req: Variant2<V1R, V2R>, ctx: ServiceCtx<'_, VariantService2<V1, V2, V1R, V2R>>, ) -> Result<<VariantService2<V1, V2, V1R, V2R> as Service<Variant2<V1R, V2R>>>::Response, <VariantService2<V1, V2, V1R, V2R> as Service<Variant2<V1R, V2R>>>::Error>
Process the request and return the response asynchronously. Read more