pub struct ConnectionInfo { /* private fields */ }Expand description
HttpRequest connection information
Implementations
Sourceimpl ConnectionInfo
impl ConnectionInfo
Sourcepub fn get<'a>(req: &'a RequestHead, cfg: &'a WebAppConfig) -> Ref<'a, Self>
pub fn get<'a>(req: &'a RequestHead, cfg: &'a WebAppConfig) -> Ref<'a, Self>
Create ConnectionInfo instance for a request.
Sourcepub fn scheme(&self) -> &str
pub fn scheme(&self) -> &str
Scheme of the request.
Scheme is resolved through the following headers, in this order:
- Forwarded
- X-Forwarded-Proto
- Uri
Sourcepub fn host(&self) -> &str
pub fn host(&self) -> &str
Hostname of the request.
Hostname is resolved through the following headers, in this order:
- Forwarded
- X-Forwarded-Host
- Uri
- Host
- Server hostname
Header values that are not a valid host[:port] are skipped.
Sourcepub fn remote(&self) -> Option<&str>
pub fn remote(&self) -> Option<&str>
Remote socket addr of client initiated HTTP request.
The addr is resolved through the following headers, in this order:
- Forwarded
- X-Forwarded-For
- peer name of opened socket
Security
Do not use this function for security purposes, unless you can ensure the Forwarded and
X-Forwarded-For headers cannot be spoofed by the client. If you want the client’s socket
address explicitly, use
HttpRequest::peer_addr() instead.