pub struct ResourceMap { /* private fields */ }Expand description
Map of registered resources, used for URL generation.
The map is built from the application’s resource definitions and is used
by HttpRequest::url_for() to resolve
named and external resources.
Implementations
Sourceimpl ResourceMap
impl ResourceMap
Sourcepub fn new(root: ResourceDef) -> Self
pub fn new(root: ResourceDef) -> Self
Create an empty resource map for the root resource.
Sourcepub fn add(
&mut self,
pattern: &mut ResourceDef,
nested: Option<Rc<ResourceMap>>,
)
pub fn add( &mut self, pattern: &mut ResourceDef, nested: Option<Rc<ResourceMap>>, )
Add a resource pattern, optionally with the resource map of a nested scope.
Assigns the pattern its id within this map. Named patterns can be used for URL generation.
Sourceimpl ResourceMap
impl ResourceMap
Sourcepub fn url_for<U, I>(
&self,
req: &HttpRequest,
name: &str,
elements: U,
) -> Result<Url, UrlGenerationError>
pub fn url_for<U, I>( &self, req: &HttpRequest, name: &str, elements: U, ) -> Result<Url, UrlGenerationError>
Generate url for named resource
Check HttpRequest::url_for() for detailed information.