WebServiceAdapter

Struct WebServiceAdapter 

pub struct WebServiceAdapter { /* private fields */ }
Create service adapter for a specific path.

use std::convert::Infallible;
use ntex::web::{self, guard, App, HttpResponse};

async fn my_service(req: web::WebRequest<()>) -> Result<web::WebResponse, Infallible> {
    Ok(req.into_response(HttpResponse::Ok().build()))
}

let app = App::default().service(
    web::service("/users/*")
        .guard(guard::Header("content-type", "text/plain"))
        .build(my_service)
);

Implementations

Source

impl WebServiceAdapter

pub fn new<T: IntoPattern>(path: T) -> Self

Create new WebServiceAdapter instance.

pub fn name(self, name: &str) -> Self

Set service name.

Name is used for url generation.

pub fn guard<G: Guard + 'static>(self, guard: G) -> Self

Add a match guard to this web service.

The service is selected only when its path and all registered guards match. If a guard rejects the request, the router can try another matching service; otherwise the containing scope or application fallback is used.

use std::convert::Infallible;
use ntex::web::{self, guard, App, HttpResponse};

async fn index(
    req: web::WebRequest<()>,
) -> Result<web::WebResponse, Infallible> {
    Ok(req.into_response(HttpResponse::Ok().build()))
}

App::default().service(
    web::service("/health")
        .guard(guard::Get())
        .guard(guard::Header("x-health-check", "true"))
        .build(index)
);
pub fn build<Sf, St, In, F>(self, service: F) -> impl WebServiceFactory<St, In>
where St: State, In: 'static, F: IntoServiceFactory<Sf, St, WebRequest<In>>, Sf: ServiceFactory<St, WebRequest<In>, Res = WebResponse> + 'static, Sf::Error: WebResponseError<St, St::Error>, Sf::InitError: IntoFailure,

Set a service factory implementation and generate web service.