pub enum PayloadError {
Http(HttpError),
Payload(PayloadError),
ContentType(ContentTypeError),
Decoding,
}Expand description
Errors that can occur while reading a request payload.
Returned by the Bytes and String extractors and by the Payload stream.
Variants
Http(HttpError)
Http error.
Payload(PayloadError)
Error while reading the payload stream.
ContentType(ContentTypeError)
Invalid content type or charset.
Decoding
The body cannot be decoded with the request’s charset.