pub fn ErrorBadGateway<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate BAD GATEWAY response.
pub fn ErrorBadGateway<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate BAD GATEWAY response.