pub fn ErrorExpectationFailed<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate EXPECTATION FAILED response.
pub fn ErrorExpectationFailed<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate EXPECTATION FAILED response.