pub fn ErrorFailedDependency<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate FAILED DEPENDENCY response.
pub fn ErrorFailedDependency<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate FAILED DEPENDENCY response.