pub fn ErrorForbidden<T, E>(err: T) -> InternalError<T, E>Expand description
Helper function that creates wrapper of any error and generate FORBIDDEN response.
pub fn ErrorForbidden<T, E>(err: T) -> InternalError<T, E>Helper function that creates wrapper of any error and generate FORBIDDEN response.