pub fn ErrorGatewayTimeout<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate GATEWAY TIMEOUT response.
pub fn ErrorGatewayTimeout<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate GATEWAY TIMEOUT response.