pub fn ErrorHttpVersionNotSupported<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate HTTP VERSION NOT SUPPORTED response.
pub fn ErrorHttpVersionNotSupported<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate HTTP VERSION NOT SUPPORTED response.