pub fn ErrorImATeapot<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate IM A TEAPOT response.
pub fn ErrorImATeapot<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate IM A TEAPOT response.