pub fn ErrorInsufficientStorage<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate INSUFFICIENT STORAGE response.
pub fn ErrorInsufficientStorage<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate INSUFFICIENT STORAGE response.