pub fn ErrorInternalServerError<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate INTERNAL SERVER ERROR response.
pub fn ErrorInternalServerError<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate INTERNAL SERVER ERROR response.