pub fn ErrorLengthRequired<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate LENGTH REQUIRED response.
pub fn ErrorLengthRequired<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate LENGTH REQUIRED response.