pub fn ErrorLoopDetected<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate LOOP DETECTED response.
pub fn ErrorLoopDetected<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate LOOP DETECTED response.