pub fn ErrorNetworkAuthenticationRequired<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate NETWORK AUTHENTICATION REQUIRED response.
pub fn ErrorNetworkAuthenticationRequired<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate NETWORK AUTHENTICATION REQUIRED response.