pub fn ErrorNotExtended<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate NOT EXTENDED response.
pub fn ErrorNotExtended<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate NOT EXTENDED response.