pub fn ErrorNotImplemented<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate NOT IMPLEMENTED response.
pub fn ErrorNotImplemented<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate NOT IMPLEMENTED response.