pub fn ErrorPayloadTooLarge<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate PAYLOAD TOO LARGE response.
pub fn ErrorPayloadTooLarge<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate PAYLOAD TOO LARGE response.