pub fn ErrorPaymentRequired<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate
PAYMENT_REQUIRED response.
pub fn ErrorPaymentRequired<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate
PAYMENT_REQUIRED response.