pub fn ErrorPreconditionFailed<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate PRECONDITION FAILED response.
pub fn ErrorPreconditionFailed<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate PRECONDITION FAILED response.