pub fn ErrorPreconditionRequired<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate PRECONDITION REQUIRED response.
pub fn ErrorPreconditionRequired<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate PRECONDITION REQUIRED response.