pub fn ErrorProxyAuthenticationRequired<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate PROXY AUTHENTICATION REQUIRED response.
pub fn ErrorProxyAuthenticationRequired<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate PROXY AUTHENTICATION REQUIRED response.