pub fn ErrorRequestTimeout<T, E>(err: T) -> InternalError<T, E>Expand description
Helper function that creates wrapper of any error and generate REQUEST TIMEOUT response.
pub fn ErrorRequestTimeout<T, E>(err: T) -> InternalError<T, E>Helper function that creates wrapper of any error and generate REQUEST TIMEOUT response.