pub fn ErrorUnauthorized<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate UNAUTHORIZED response.
pub fn ErrorUnauthorized<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate UNAUTHORIZED response.