pub fn ErrorUnprocessableEntity<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate UNPROCESSABLE ENTITY response.
pub fn ErrorUnprocessableEntity<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate UNPROCESSABLE ENTITY response.