pub fn ErrorUnsupportedMediaType<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate UNSUPPORTED MEDIA TYPE response.
pub fn ErrorUnsupportedMediaType<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate UNSUPPORTED MEDIA TYPE response.