pub fn ErrorUpgradeRequired<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate UPGRADE REQUIRED response.
pub fn ErrorUpgradeRequired<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate UPGRADE REQUIRED response.