pub fn ErrorUriTooLong<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate URI TOO LONG response.
pub fn ErrorUriTooLong<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate URI TOO LONG response.