pub fn ErrorVariantAlsoNegotiates<T>(err: T) -> InternalError<T>Expand description
Helper function that creates wrapper of any error and generate VARIANT ALSO NEGOTIATES response.
pub fn ErrorVariantAlsoNegotiates<T>(err: T) -> InternalError<T>Helper function that creates wrapper of any error and generate VARIANT ALSO NEGOTIATES response.