WebError

Struct WebError 

pub struct WebError<St = (), Err = DefaultError>(/* private fields */);
Type-erased web error for the Err error domain.

Web services, middleware, and filters use WebError as their error type. It stores any error that implements WebResponseError for the same application state and error domain, and renders it with that implementation.

Implementations

Source

impl<St: 'static, Err: 'static> WebError<St, Err>

pub fn from_err<E: WebResponseError<St, Err>>(err: E) -> Self

Create WebError from an error that can be rendered for this domain.