AppState

Struct AppState 

pub struct AppState<T> { /* private fields */ }
Wraps a value so it can be used as application state with DefaultError.

AppState<T> implements State for any 'static T, so a separate State implementation is not needed. It dereferences to the wrapped value and implements Clone and Default when T does.

use ntex::web;

#[derive(Clone)]
struct Settings {
    service_name: &'static str,
}

let state = web::AppState::new(Settings { service_name: "users" });
assert_eq!(state.service_name, "users");

Implementations

Source

impl<T> AppState<T>

pub fn new(state: T) -> Self

Creates application state that wraps state.

pub fn st(&self) -> &T

Returns a reference to the wrapped value.