WebAppConfig

Struct WebAppConfig 

pub struct WebAppConfig { /* private fields */ }
Application configuration

Implementations

Source

impl WebAppConfig

pub fn new() -> Self

Create an default WebAppConfig instance.

pub fn with(name: &str, secure: bool, addr: SocketAddr, host: String) -> Self

Create an WebAppConfig instance.

pub fn name(&self) -> &ByteString

Server name

pub fn host(&self) -> &str

Server host name

Host name is used by application router as a hostname for url generation. Check ConnectionInfo::host() documentation for more information.

By default host name is set to a “localhost:8080” value.

pub fn secure(&self) -> bool

Returns true if connection is secure(https)

pub fn local_addr(&self) -> SocketAddr

Returns the socket address of the local half of this TCP connection

pub fn state<T: 'static>(&self) -> Option<&T>

Get an application state object stored with .set_state() method.

pub fn set_host(self, host: String) -> Self

Set server host name.

By default host name is set to a “localhost:8080” value.

pub fn set_secure(self) -> Self

Connection is secure(https).

pub fn set_local_addr(self, addr: SocketAddr) -> Self

Set the socket address of the local half of the TCP connection.

pub fn set_pool_size(self, size: usize) -> Self

Set size of HttpRequest pool size.

By default pool size is 128.

pub fn set_state<T: Send + Sync + 'static>(self, val: T) -> Self

Set application level arbitrary state item.

Application state stored with .set_state() method is available via HttpRequest::app_state() method at runtime.