WebRequest

Struct WebRequest 

pub struct WebRequest<St = ()> { /* private fields */ }
An service http request

WebRequest allows mutable access to request’s internal structures

Implementations

Source

impl<St> WebRequest<St>

pub fn error_response<AppSt, E>(self, st: &AppSt, err: &E) -> WebResponse
where AppSt: State, E: WebResponseError<AppSt, AppSt::Error>,

Create web response for error

Source

impl WebRequest<()>

pub fn from_request(req: HttpRequest) -> Self

Construct request from request.

Source

impl<St> WebRequest<St>

pub fn into_parts(self) -> (HttpRequest, Payload, St)

Deconstruct request into parts

pub fn from_parts(req: HttpRequest, payload: Payload, state: St) -> Self

Construct request from parts.

pub fn into_response<R: Into<Response>>(self, res: R) -> WebResponse

Create web response

pub fn io(&self) -> Option<&IoRef>

Io reference for current connection

pub fn head(&self) -> &RequestHead

This method returns reference to the request head

pub fn head_mut(&mut self) -> &mut RequestHead

This method returns mutable reference to the request head

pub fn uri(&self) -> &Url

Request’s uri.

pub fn method(&self) -> &Method

Read the Request method.

pub fn version(&self) -> Version

Read the Request Version.

pub fn headers(&self) -> &HeaderMap

Returns request’s headers.

pub fn headers_mut(&mut self) -> &mut HeaderMap

Returns mutable request’s headers.

pub fn path(&self) -> &str

The target path of this Request.

pub fn query_string(&self) -> &str

The query string in the URL.

E.g., id=10

pub fn peer_addr(&self) -> Option<SocketAddr>

Peer socket address

Peer address is actual socket address, if proxy is used in front of ntex http server, then peer address would be address of this proxy.

To get client connection information ConnectionInfo should be used.

pub fn take_payload(&mut self) -> Payload

Take request’s payload.

The payload is replaced with an empty one, so subsequent calls return an empty payload.

pub fn set_payload(&mut self, payload: Payload)

Set request payload.

pub fn connection_info(&self) -> Ref<'_, ConnectionInfo>

Get ConnectionInfo for the current request.

pub fn match_info(&self) -> &Path<Url>

Get a reference to the Path parameters.

Params is a container for url parameters. A variable segment is specified in the form {identifier}, where the identifier can be used later in a request handler to access the matched value for that segment.

pub fn match_info_mut(&mut self) -> &mut Path<Url>

Get a mutable reference to the Path parameters.

pub fn resource_map(&self) -> &ResourceMap

Get a reference to a ResourceMap of current application.

pub fn app_config(&self) -> &WebAppConfig

Service configuration

pub fn app_state<T: 'static>(&self) -> Option<&T>

Get an application state.

pub fn extensions(&self) -> Ref<'_, Extensions>

Request extensions

pub fn extensions_mut(&self) -> RefMut<'_, Extensions>

Mutable reference to a the request’s extensions

pub fn st(&self) -> &St

Get request state ref.

pub fn st_mut(&mut self) -> &mut St

Get request state mut ref

pub fn map_state<F, NewSt>(self, f: F) -> WebRequest<NewSt>
where F: FnOnce(St) -> NewSt,

Transform the request state into a new type.

This method consumes the request and returns request with different state a WebRequest<NewSt>. The HTTP request and payload are preserved. It is useful in application and resource filters that add request-specific data before passing the request to the next service.

Application state is not affected; only the state stored in this WebRequest is replaced.

use std::convert::Infallible;
use ntex::web::{self, WebRequest};

async fn index(_: &(), user_id: usize) -> String {
    format!("User {user_id}")
}

web::App::default()
    .filter(async |req: WebRequest<()>| {
        Ok::<_, Infallible>(req.map_state(|()| 42usize))
    })
    .service(web::resource("/").to_with_state(index));