TestRequest

Struct TestRequest 

pub struct TestRequest<St = ()> { /* private fields */ }
Test Request builder.

For unit testing, ntex provides a request builder type and a simple handler runner. TestRequest implements a builder-like pattern. You can generate various types of request via TestRequest’s methods:

  • TestRequest::to_request creates ntex::http::Request instance.
  • TestRequest::to_srv_request creates WebRequest instance, which is used for testing middlewares and chain adapters.
  • TestRequest::to_srv_response creates WebResponse instance.
  • TestRequest::to_http_request creates HttpRequest instance, which is used for testing handlers.
use ntex::http::{header, StatusCode, HttpMessage};
use ntex::web::{self, test, HttpRequest, HttpResponse};

async fn index(req: HttpRequest) -> HttpResponse {
    if req.headers().contains_key(header::CONTENT_TYPE) {
        HttpResponse::Ok().into()
    } else {
        HttpResponse::BadRequest().into()
    }
}

#[ntex::test]
async fn test_index() {
    let req = test::TestRequest::with_header("content-type", "text/plain")
        .to_http_request();

    let resp = index(req).await;
    assert_eq!(resp.status(), StatusCode::OK);

    let req = test::TestRequest::default().to_http_request();
    let resp = index(req).await;
    assert_eq!(resp.status(), StatusCode::BAD_REQUEST);
}

Implementations

Source

impl TestRequest

pub fn with_uri(path: &str) -> TestRequest

Create TestRequest and set request uri.

pub fn with_header<K, V>(key: K, value: V) -> TestRequest

Create TestRequest and set header.

pub fn get() -> TestRequest

Create TestRequest and set method to Method::GET.

pub fn post() -> TestRequest

Create TestRequest and set method to Method::POST.

pub fn put() -> TestRequest

Create TestRequest and set method to Method::PUT.

pub fn patch() -> TestRequest

Create TestRequest and set method to Method::PATCH.

pub fn delete() -> TestRequest

Create TestRequest and set method to Method::DELETE.

Source

impl<St> TestRequest<St>

pub fn version(self, ver: Version) -> Self

Set HTTP version of this request.

pub fn method(self, meth: Method) -> Self

Set HTTP method of this request.

pub fn uri(self, path: &str) -> Self

Set HTTP Uri of this request.

pub fn header<K, V>(self, key: K, value: V) -> Self

Set a header.

pub fn cookie<C>(self, cookie: C) -> Self
where C: Into<Cookie<'static>>,

Set cookie for this request.

pub fn param(self, name: &'static str, value: &'static str) -> Self

Set request path pattern parameter.

pub fn peer_addr(self, addr: SocketAddr) -> Self

Set peer addr.

The address is returned by peer_addr() of the generated request. Requests with a peer address must be created inside the ntex runtime.

pub fn payload<B: Into<Bytes>>(self, data: B) -> Self

Set request payload.

pub fn form<T: Serialize>(self, data: &T) -> Self

Serialize data to a URL encoded form and set it as the request payload.

The Content-Type header is set to application/x-www-form-urlencoded.

pub fn json<T: Serialize>(self, data: &T) -> Self

Serialize data to JSON and set it as the request payload.

The Content-Type header is set to application/json.

pub fn state<NewSt: 'static>(self, state: NewSt) -> TestRequest<NewSt>

Set request state.

pub fn app_state<T: Send + Sync + 'static>(self, data: T) -> Self

Set application state.

This is equivalent of WebAppConfig::set_state() method for testing purpose. The value is available via HttpRequest::app_state().

pub fn to_request(self) -> Request

Complete request creation and generate Request instance.

pub fn to_srv_request(self) -> WebRequest<St>

Complete request creation and generate WebRequest instance.

pub fn to_srv_response(self, res: HttpResponse) -> WebResponse

Complete request creation and generate WebResponse instance.

pub fn to_http_request(self) -> HttpRequest

Complete request creation and generate HttpRequest instance.

pub fn to_http_parts(self) -> (HttpRequest, Payload, St)

Complete request creation and generate HttpRequest and Payload instances.