TestServerConfig

Struct TestServerConfig 

pub struct TestServerConfig { /* private fields */ }
Test server configuration

Implementations

Source

impl TestServerConfig

pub fn h1(self) -> Self

Start http/1.1 server only.

pub fn h2(self) -> Self

Start http/2 server only.

pub fn openssl(self, acceptor: SslAcceptor) -> Self

Start openssl server.

pub fn rustls(self, config: ServerConfig) -> Self

Start rustls server.

pub fn client_timeout(self, val: Seconds) -> Self

Set server client timeout in seconds for first request.

pub fn port(self, port: u16) -> Self

Set server port. By default, test server binds to a random port assigned by OS.

pub fn listener(self, listener: TcpListener) -> Self

Use an already bound TCP listener for the test server.

When set, the configured port is ignored.

pub fn server_cfg(self, cfg: impl Into<SharedCfg>) -> Self

Use custom SharedCfg for test server.

pub fn client_cfg(self, cfg: impl Into<SharedCfg>) -> Self

Use custom SharedCfg for client.