pub trait HandlerSt<St, U, T>: 'staticwhere
St: State,{
type Output: Responder<St>;
// Required method
async fn call(&self, st: &St, req: U, param: T) -> Self::Output;
}Expand description
Async fn handler that receives the application and request state.
Implemented for async functions and closures whose first two arguments are
the application state &St and the request state U, followed by up to 16
extractors. T is the tuple of extractor types. Register such handlers with
Route::to_with_state().
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".