Payload

Struct Payload 

pub struct Payload(pub Payload);
Payload extractor returns request’s payload stream.

Example

use std::future::Future;
use ntex::util::{BytesMut, Stream};
use ntex::web::{self, error, App, HttpResponse};

/// extract binary data from request
async fn index(mut body: web::types::Payload) -> Result<HttpResponse, error::PayloadError>
{
    let mut bytes = BytesMut::new();
    while let Some(item) = ntex::util::stream_recv(&mut body).await {
        bytes.extend_from_slice(&item?);
    }

    format!("Body {:?}!", bytes);
    Ok(HttpResponse::Ok().build())
}

fn main() {
    let app = App::default().service(
        web::resource("/index.html").route(
            web::get().to(index))
    );
}

Tuple Fields

0: Payload

Implementations

Source

impl Payload

pub fn into_inner(self) -> Payload

Deconstruct to a inner value

pub async fn recv(&mut self) -> Option<Result<Bytes, PayloadError>>

Attempt to pull out the next value of this payload.

pub fn poll_recv( &mut self, cx: &mut Context<'_>, ) -> Poll<Option<Result<Bytes, PayloadError>>>

Attempt to pull out the next value of this payload, registering the current task for wakeup if the value is not yet available, and returning None if the payload is exhausted.