pub enum CloseCode {
Show 15 variants
Normal,
Away,
Protocol,
Unsupported,
Abnormal,
Invalid,
Policy,
Size,
Extension,
Error,
Restart,
Again,
BadGateway,
Tls,
Other(u16),
}Expand description
Status code used to indicate why an endpoint is closing the WebSocket
connection.
Variants
Normal
Indicates a normal closure, meaning that the purpose for which the connection was established has been fulfilled.
Away
Indicates that an endpoint is “going away”, such as a server going down or a browser having navigated away from a page.
Protocol
Indicates that an endpoint is terminating the connection due to a protocol error.
Unsupported
Indicates that an endpoint is terminating the connection because it has received a type of data it cannot accept (e.g., an endpoint that understands only text data MAY send this if it receives a binary message).
Abnormal
Indicates that the connection closed without a close control frame.
This code is reserved for local reporting and cannot be sent in a close frame.
Invalid
Indicates that an endpoint is terminating the connection because it has received data within a message that was not consistent with the type of the message (e.g., non-UTF-8 [RFC3629] data within a text message).
Policy
Indicates that an endpoint is terminating the connection because it has received a message that violates its policy. This is a generic status code that can be returned when there is no other more suitable status code (e.g., Unsupported or Size) or if there is a need to hide specific details about the policy.
Size
Indicates that an endpoint is terminating the connection because it has received a message that is too big for it to process.
Extension
Indicates that an endpoint (client) is terminating the connection because it has expected the server to negotiate one or more extension, but the server didn’t return them in the response message of the WebSocket handshake. The list of extensions that are needed should be given as the reason for closing. Note that this status code is not used by the server, because it can fail the WebSocket handshake instead.
Error
Indicates that a server is terminating the connection because it encountered an unexpected condition that prevented it from fulfilling the request.
Restart
Indicates that the server is restarting. A client may choose to reconnect, and if it does, it should use a randomized delay of 5-30 seconds between attempts.
Again
Indicates that the server is overloaded and the client should either connect to a different IP (when multiple targets exist), or reconnect to the same IP when a user has performed an action.
BadGateway
Indicates that an upstream server returned an invalid response.
Tls
Indicates that the TLS handshake failed.
This code is reserved for local reporting and cannot be sent in a close frame.
Other(u16)
An unrecognized or application-defined close code.
Only values in the range 3000 through 4999 can be sent.