pub enum ProtocolError {
}Expand description
WebSocket protocol errors.
Variants
UnmaskedFrame
Received an unmasked frame from client
MaskedFrame
Received a masked frame from server
InvalidOpcode(u8)
Encountered invalid opcode
ReservedBits(u8)
Reserved frame bits are set without a negotiated extension.
FragmentedControlFrame(OpCode)
A control frame is fragmented.
InvalidLength(usize)
Invalid control frame length
InvalidLengthEncoding
A payload length does not use its shortest valid encoding.
InvalidCloseCode(u16)
Invalid close status code.
InvalidClosePayload
Invalid close-frame payload.
InvalidUtf8
A close-frame description is not valid UTF-8.
Closed
A message was encoded after a close message.
Overflow
A payload reached size limit.
ContinuationNotStarted
Continuation is not started
ContinuationStarted
Received new continuation but it is already started