Codec

Struct Codec 

pub struct Codec { /* private fields */ }
Encoder and decoder for WebSocket frames.

Implementations

Source

impl Codec

pub fn new() -> Codec

Creates a codec in server mode with a 64 KiB frame-size limit.

pub fn max_size(self, size: usize) -> Self

Sets the maximum accepted frame payload size.

The default is 64 KiB.

pub fn set_client_mode(self) -> Self

Configures the codec for client-side masking rules.

Client mode masks encoded frames and rejects masked incoming frames. By default, the codec uses server-side masking rules.

pub fn is_closed(&self) -> bool

Returns true after this codec has encoded a close message.

pub fn encode_page( &self, page: BytePage, dst: &mut BytePages, ) -> Result<(), ProtocolError>

Encodes page as a final binary frame.

Errors

Returns ProtocolError::Closed if a close message has already been encoded, or ProtocolError::ContinuationStarted if a fragmented message is in progress.