WsClient

Struct WsClient 

pub struct WsClient<F> { /* private fields */ }
Builder for establishing a WebSocket client connection.

The builder contains the target URI and a typed WsClientConfig. Use connect to perform the opening handshake.

Implementations

Source

impl WsClient<Base>

pub fn new<U>(uri: U, cfg: impl Into<Cfg<WsClientConfig>>) -> Self
where Url: TryFrom<U>, WsConfigError: From<<Url as TryFrom<U>>::Error>,

Creates a client for uri using the supplied configuration.

use ntex::{SharedCfg, time::Seconds};
use ntex::ws::{WsClient, WsClientConfig};

#[ntex::main]
async fn main() {
    let cfg = SharedCfg::new("WS-CLIENT").add(
        WsClientConfig::new()
            .set_max_frame_size(128 * 1024)
            .set_handshake_timeout(Seconds(10))
    );

    let _client = WsClient::new("ws://localhost/socket", cfg);
}

URI conversion and validation errors are stored and returned by connect.

Source

impl<F> WsClient<F>

pub fn connector<U, S>( self, f: impl IntoService<S, SharedCfg, Connect<Url>>, ) -> WsClient<U>
where U: Filter + 'static, S: Service<SharedCfg, Connect<Url>, Res = Io<U>, Error = Error<ConnectError>> + 'static,

Replaces the network connector used to establish the connection.

pub fn openssl(self, config: SslConnector) -> WsClient<Layer<SslFilter>>

Uses the supplied OpenSSL connector for secure connections.

pub fn rustls( self, config: Arc<RustlsClientConfig>, ) -> WsClient<Layer<TlsClientFilter>>

Uses the supplied rustls connector for secure connections.

Source

impl<F> WsClient<F>
where F: Filter,

pub async fn connect(&self) -> Result<WsConnection<F>, Error<WsClientError>>

Establishes the connection and performs the WebSocket opening handshake.

Errors

Returns an error if connection establishment, HTTP encoding or decoding, URI validation, timeout handling, or handshake validation fails.