pub struct Receiver<T> { /* private fields */ }Expand description
The receiving end of a channel which implements the Stream trait.
This is created by the channel function.
Implementations
Sourceimpl<T> Receiver<T>
impl<T> Receiver<T>
Sourcepub fn close(&self)
pub fn close(&self)
Closes the receiving half of a channel, without dropping it.
This prevents any further messages from being sent on the channel while still enabling the receiver to drain messages that are buffered.