Http client errors
Structs
Enums
- Client
Builder Error - A set of errors that can occur while building HTTP client
- Client
Error - A set of errors that can occur during request sending and response reading
- Connect
Error - A set of errors that can occur while connecting to an HTTP host
- Invalid
Url - Json
Payload Error - A set of errors that can occur during parsing json payloads