Module error

Module error 

Http client errors

Enums

ClientBuilderError
A set of errors that can occur while building HTTP client
ConnectError
A set of errors that can occur while connecting to an HTTP host
InvalidUrl
JsonPayloadError
A set of errors that can occur during parsing json payloads
SendRequestError
A set of errors that can occur during request sending and response reading