Http client errors
Enums
- Client
Builder Error - A set of errors that can occur while building HTTP client
- Connect
Error - A set of errors that can occur while connecting to an HTTP host
- Invalid
Url - Json
Payload Error - A set of errors that can occur during parsing json payloads
- Send
Request Error - A set of errors that can occur during request sending and response reading