pub struct Connect<T> { /* private fields */ }Expand description
Request to resolve and connect to a remote address.
Implementations
Sourceimpl<T> Connect<T>where
T: Address,
impl<T> Connect<T>where
T: Address,
Sourcepub fn new(req: T) -> Connect<T>
pub fn new(req: T) -> Connect<T>
Creates a connection request and derives a port from the host when present.
Sourcepub fn with(req: T, addr: SocketAddr) -> Connect<T>
pub fn with(req: T, addr: SocketAddr) -> Connect<T>
Creates a request with a pre-resolved socket address.
The connector skips DNS resolution for this request.
Sourcepub fn set_port(self, port: u16) -> Connect<T>
pub fn set_port(self, port: u16) -> Connect<T>
Sets the port used when Address::port() does not provide one.
This replaces the port parsed from a host:port host by
new(), which is zero if the host has none.
Sourcepub fn set_addr(self, addr: Option<SocketAddr>) -> Connect<T>
pub fn set_addr(self, addr: Option<SocketAddr>) -> Connect<T>
Sets one pre-resolved socket address.
Sourcepub fn set_addrs<I>(self, addrs: I) -> Connect<T>where
I: IntoIterator<Item = SocketAddr>,
pub fn set_addrs<I>(self, addrs: I) -> Connect<T>where
I: IntoIterator<Item = SocketAddr>,
Sets multiple pre-resolved socket addresses.
Sourcepub fn port(&self) -> u16
pub fn port(&self) -> u16
Returns the port from Address::port(), or the one parsed from the
host or set by set_port().
Sourcepub fn addrs(&self) -> ConnectAddrsIter<'_>
pub fn addrs(&self) -> ConnectAddrsIter<'_>
Iterates over the request’s pre-resolved addresses.
Sourcepub fn take_addrs(&mut self) -> ConnectTakeAddrsIter
pub fn take_addrs(&mut self) -> ConnectTakeAddrsIter
Removes and returns the request’s pre-resolved addresses.