Module error

Module error 

Modules

utils

Structs

Backtrace
Representation of a backtrace.
BacktraceResolver
Backtrace resolver.
Error
An error container.
ErrorChain
A type-erased container representing an error within a diagnostic chain.
ErrorInfo
Type-erased container holding error information.
ErrorMessage
ErrorMessageChained
Success

Enums

ResultType
The type of the result.

Traits

ErrorDiagnostic
Provides diagnostic information for errors.
ErrorMapping
Helper trait for converting a value into a unified error-aware result type.
ResultKind
Describes how a domain-specific error maps into a unified result model.

Functions

fmt_diag
Formats a full diagnostic view of an error for logging and tracing.
fmt_diag_string
Formats a full diagnostic view of an error for logging and tracing.
fmt_err
fmt_err_string
set_backtrace_start
with_service
Executes a future and ensures an error service is set.