Modules
Structs
- Backtrace
- Representation of a backtrace.
- Backtrace
Resolver - Backtrace resolver.
- Error
- An error container.
- Error
Chain - A type-erased container representing an error within a diagnostic chain.
- Error
Info - Type-erased container holding error information.
- Error
Message - Error
Message Chained - Success
Enums
- Result
Type - The type of the result.
Traits
- Error
Diagnostic - Provides diagnostic information for errors.
- Error
Mapping - Helper trait for converting a value into a unified error-aware result type.
- Result
Kind - Describes how a domain-specific error maps into a unified result model.
Functions
- fmt_
diag - Formats a full diagnostic view of an error for logging and tracing.
- fmt_
diag_ string - Formats a full diagnostic view of an error for logging and tracing.
- fmt_err
- fmt_
err_ string - set_
backtrace_ start - with_
service - Executes a future and ensures an error service is set.