pub fn set_backtrace_start(file: &'static str, line: u32)Expand description
Sets the source location where rendered backtraces are cut off.
The frame matching file (a path suffix) and line (0 matches any line),
and all of its callers, are omitted from the rendered backtrace.
Must be called once during initialization, before any backtrace is resolved.