pub async fn with_service<F, T, E>(
svc: &'static str,
fut: F,
) -> <F as Future>::OutputExpand description
Executes a future and ensures an error service is set.
If the error does not already have a service, the provided service is assigned.