pub enum ResponseBody<B> {
Body(B),
Other(Body),
}Expand description
Response body preserving either a concrete body type or a type-erased body.
Variants
Implementations
Sourceimpl ResponseBody<Body>
impl ResponseBody<Body>
Sourcepub fn into_body<B>(self) -> ResponseBody<B>
pub fn into_body<B>(self) -> ResponseBody<B>
Converts a type-erased response body to another concrete response type.
Sourceimpl<B> ResponseBody<B>
impl<B> ResponseBody<B>
Sourcepub fn new(body: B) -> ResponseBody<B>
pub fn new(body: B) -> ResponseBody<B>
Creates a response body from a concrete body value.
Sourcepub fn take_body(&mut self) -> ResponseBody<B>
pub fn take_body(&mut self) -> ResponseBody<B>
Replaces this response body with Body::None and returns the original.
Sourceimpl<B> ResponseBody<B>where
B: MessageBody,
impl<B> ResponseBody<B>where
B: MessageBody,
Sourcepub fn as_ref(&self) -> Option<&B>
pub fn as_ref(&self) -> Option<&B>
Returns the concrete body, if this is ResponseBody::Body.