Http related errors
Structs
- Canceled
- Error returned from a
Receiverwhen the correspondingSenderis dropped. - Http
Error - A generic “error” for HTTP connections
Enums
- Blocking
Error - Blocking operation execution error
- Content
Type Error - A set of error that can occure during parsing content type
- Decode
Error - A set of errors that can occur during parsing HTTP streams
- Dispatch
Error - A set of errors that can occur during dispatching http requests
- Encode
Error - A set of errors that can occur during HTTP streams encoding
- H2Error
- A set of errors that can occur during dispatching http2 requests
- Payload
Error - A set of errors that can occur during payload parsing
Traits
- Response
Error - Error that can be converted to
Response