pub enum Control<F, Err> {
Connect(Connection<F>),
Request(NewRequest),
Upgrade(Upgrade<F>),
Expect(Expect),
Disconnect(Reason<Err>),
}Expand description
A lifecycle event sent to an HTTP/1 control service.
Return Control::ack to accept the default action, or use the methods on
the individual message type to reject or take ownership of the operation.
Variants
Connect(Connection<F>)
A transport connection has been accepted.
Request(NewRequest)
A complete request head has been decoded.
Upgrade(Upgrade<F>)
A request asks to upgrade the HTTP/1 connection.
Expect(Expect)
A request contains Expect: 100-continue.
Disconnect(Reason<Err>)
The connection is preparing to stop.
Implementations
Sourceimpl<F, Err> Control<F, Err>
impl<F, Err> Control<F, Err>
Sourcepub fn ack(self) -> ControlAck<F>where
F: Filter,
Err: ResponseError,
pub fn ack(self) -> ControlAck<F>where
F: Filter,
Err: ResponseError,
Accepts the event and applies its default action.