pub struct Expect(/* private fields */);Expand description
A request containing an Expect: 100-continue header.
Implementations
Sourceimpl Expect
impl Expect
Sourcepub fn ack<F>(self) -> ControlAck<F>
pub fn ack<F>(self) -> ControlAck<F>
Sends 100 Continue and passes the request to the application service.
Sourcepub fn fail<E: ResponseError, F>(self, err: E) -> ControlAck<F>
pub fn fail<E: ResponseError, F>(self, err: E) -> ControlAck<F>
Rejects the expectation with the response generated from err.
Sourcepub fn fail_with<F>(self, res: Response) -> ControlAck<F>
pub fn fail_with<F>(self, res: Response) -> ControlAck<F>
Rejects the expectation with a custom response.