pub struct Upgrade<F> { /* private fields */ }Expand description
A request to upgrade the HTTP/1 connection.
Implementations
Sourceimpl<F: Filter> Upgrade<F>
impl<F: Filter> Upgrade<F>
Sourcepub fn ack(self) -> ControlAck<F>
pub fn ack(self) -> ControlAck<F>
Passes the upgrade request to the application service.
The application can take ownership of the connection and codec through
RequestHead::take_io.
Sourcepub fn handle(self) -> (ControlAck<F>, Io<F>, Request, Codec)
pub fn handle(self) -> (ControlAck<F>, Io<F>, Request, Codec)
Takes ownership of the connection, request, and codec.
Returning this acknowledgement tells the dispatcher that the control service is responsible for the upgraded connection.
Sourcepub fn fail<E: ResponseError>(self, err: E) -> ControlAck<F>
pub fn fail<E: ResponseError>(self, err: E) -> ControlAck<F>
Rejects the upgrade with the response generated from err.
Sourcepub fn fail_with(self, res: Response) -> ControlAck<F>
pub fn fail_with(self, res: Response) -> ControlAck<F>
Rejects the upgrade with a custom response.