pub struct H1Service<F, Req: RequestState<Io<F>>, Err> { /* private fields */ }Expand description
Server transport service that dispatches HTTP/1 requests.
Construct this service with HttpService::h1.
Request handling is delegated to the configured application service, while
connection lifecycle events get their default action unless a control
service is provided with control.
Implementations
Sourceimpl<F, Req, Err> H1Service<F, Req, Err>
impl<F, Req, Err> H1Service<F, Req, Err>
Sourcepub fn control<I, Sf>(self, ctl: I) -> Selfwhere
I: IntoServiceFactory<Sf, Req::State, Control<F, Err>>,
Sf: ServiceFactory<Req::State, Control<F, Err>, Res = ControlAck<F>> + 'static,
Sf::Error: IntoFailure,
Sf::InitError: IntoFailure,
pub fn control<I, Sf>(self, ctl: I) -> Selfwhere
I: IntoServiceFactory<Sf, Req::State, Control<F, Err>>,
Sf: ServiceFactory<Req::State, Control<F, Err>, Res = ControlAck<F>> + 'static,
Sf::Error: IntoFailure,
Sf::InitError: IntoFailure,
Provides the HTTP/1 control service.
The control service receives connection, request, expectation, upgrade,
and disconnect events. Service and protocol errors are reported by the
disconnect event. Returning Control::ack applies the
default action for each event.