Payload

Struct Payload 

pub struct Payload { /* private fields */ }
Buffered stream of byte chunks

Payload stores chunks in a vector. First chunk can be received with .readany() method. Payload stream is not thread safe. Payload does not notify current task when new data is available.

Payload stream can be used as Response body stream.

Implementations

Source

impl Payload

pub fn create(cap: Capacity) -> (PayloadSender, Payload)

Create payload stream.

This method construct two objects responsible for bytes stream generation.

  • PayloadSender - Sender side of the stream

  • Payload - Receiver side of the stream

pub async fn read(&self) -> Option<Result<Bytes, PayloadError>>

pub fn poll_read( &self, cx: &mut Context<'_>, ) -> Poll<Option<Result<Bytes, PayloadError>>>