pub struct Request { /* private fields */ }Expand description
An HTTP request.
Implementations
Sourceimpl Request
impl Request
Sourcepub fn with_payload(payload: Payload) -> Request
pub fn with_payload(payload: Payload) -> Request
Creates a request with the supplied payload.
Sourcepub fn head(&self) -> &RequestHead
pub fn head(&self) -> &RequestHead
Returns the request head.
Sourcepub fn headers_mut(&mut self) -> &mut HeaderMap
pub fn headers_mut(&mut self) -> &mut HeaderMap
Returns mutable access to the request headers.
Sourcepub fn io(&self) -> Option<&IoRef>
pub fn io(&self) -> Option<&IoRef>
Returns the I/O object for the current connection, when available.
Sourcepub fn peer_addr(&self) -> Option<SocketAddr>
pub fn peer_addr(&self) -> Option<SocketAddr>
Returns the peer socket address.
Peer address is actual socket address, if proxy is used in front of ntex http server, then peer address would be address of this proxy.
Sourcepub fn take_payload(&mut self) -> Payload
pub fn take_payload(&mut self) -> Payload
Takes the request payload, leaving an empty payload behind.
Sourcepub fn replace_payload(&mut self, payload: Payload) -> Payload
pub fn replace_payload(&mut self, payload: Payload) -> Payload
Replaces the request payload and returns the previous value.
Sourcepub fn extensions(&self) -> Ref<'_, Extensions>
pub fn extensions(&self) -> Ref<'_, Extensions>
Returns the request extensions.
Sourcepub fn extensions_mut(&self) -> RefMut<'_, Extensions>
pub fn extensions_mut(&self) -> RefMut<'_, Extensions>
Returns mutable access to the request extensions.