Request

Struct Request 

pub struct Request { /* private fields */ }
Request

Implementations

Source

impl Request

pub fn new() -> Request

Create new Request instance

Source

impl Request

pub fn with_payload(payload: Payload) -> Request

Create new Request instance

pub fn head(&self) -> &RequestHead

Http message part of the request

pub fn uri(&self) -> &Uri

Request’s uri.

pub fn uri_mut(&mut self) -> &mut Uri

Mutable reference to the request’s uri.

pub fn method(&self) -> &Method

Read the Request method.

pub fn version(&self) -> Version

Read the Request Version.

pub fn path(&self) -> &str

The target path of this Request.

pub fn headers(&self) -> &HeaderMap

Request’s headers.

pub fn headers_mut(&mut self) -> &mut HeaderMap

Mutable reference to the message’s headers.

pub fn upgrade(&self) -> bool

Check if request requires connection upgrade

pub fn io(&self) -> Option<&IoRef>

Io reference for current connection

pub fn peer_addr(&self) -> Option<SocketAddr>

Peer socket address

Peer address is actual socket address, if proxy is used in front of ntex http server, then peer address would be address of this proxy.

pub fn payload(&mut self) -> &mut Payload

Get request’s payload

pub fn take_payload(&mut self) -> Payload

Get request’s payload

pub fn replace_payload(&mut self, payload: Payload) -> Payload

Replace request’s payload, returns old one

pub fn extensions(&self) -> Ref<'_, Extensions>

Request extensions

pub fn extensions_mut(&self) -> RefMut<'_, Extensions>

Mutable reference to a the request’s extensions