RequestHead

Struct RequestHead 

pub struct RequestHead {
    pub id: usize,
    pub uri: Uri,
    pub method: Method,
    pub version: Version,
    pub headers: HeaderMap,
    pub extensions: RefCell<Extensions>,
    /* private fields */
}

Fields

id: usizeuri: Urimethod: Methodversion: Versionheaders: HeaderMapextensions: RefCell<Extensions>

Implementations

Source

impl RequestHead

pub fn extensions(&self) -> Ref<'_, Extensions>

Message extensions

pub fn extensions_mut(&self) -> RefMut<'_, Extensions>

Mutable reference to a the message’s extensions

pub fn headers(&self) -> &HeaderMap

Read the message headers.

pub fn headers_mut(&mut self) -> &mut HeaderMap

Mutable reference to the message headers.

pub fn set_connection_type(&mut self, ctype: ConnectionType)

Set connection type of the message

pub fn connection_type(&self) -> ConnectionType

Connection type

pub fn upgrade(&self) -> bool

Connection upgrade status

pub fn expect(&self) -> bool

Request contains EXPECT header

pub fn chunked(&self) -> bool

Get response body chunking state

pub fn no_chunking(&mut self, val: bool)

pub fn peer_addr(&self) -> Option<SocketAddr>

Peer socket address

Peer address is actual socket address, if proxy is used in front of ntex http server, then peer address would be address of this proxy.

pub fn take_io(&self) -> Option<(IoBoxed, Codec)>

Take io and codec for current request

This objects are set only for upgrade requests