ResponseBuilder

Struct ResponseBuilder 

pub struct ResponseBuilder { /* private fields */ }
An HTTP response builder

This type can be used to construct an instance of Response through a builder-like pattern.

Implementations

Source

impl ResponseBuilder

pub fn new(status: StatusCode) -> Self

Create response builder

pub fn status(&mut self, status: StatusCode) -> &mut Self

Set HTTP status code of this response.

pub fn header<K, V>(&mut self, key: K, value: V) -> &mut Self

Append a header to existing headers.

use ntex::http::{header, Request, Response};

fn index(req: Request) -> Response {
    Response::Ok()
        .header("X-TEST", "value")
        .header(header::CONTENT_TYPE, "application/json")
        .finish()
}
pub fn set_header<K, V>(&mut self, key: K, value: V) -> &mut Self

Set a header.

use ntex::http::{header, Request, Response};

fn index(req: Request) -> Response {
    Response::Ok()
        .set_header("X-TEST", "value")
        .set_header(header::CONTENT_TYPE, "application/json")
        .finish()
}
pub fn reason(&mut self, reason: &'static str) -> &mut Self

Set the custom reason for the response.

pub fn keep_alive(&mut self) -> &mut Self

Set connection type to KeepAlive

pub fn upgrade<V>(&mut self, value: V) -> &mut Self

Set connection type to Upgrade

pub fn force_close(&mut self) -> &mut Self

Force close connection, even if it is marked as keep-alive

pub fn no_chunking(&mut self) -> &mut Self

Disable chunked transfer encoding for HTTP/1.1 streaming responses.

pub fn content_type<V>(&mut self, value: V) -> &mut Self

Set response content type.

pub fn content_length(&mut self, len: u64) -> &mut Self

Set content length.

pub fn cookie<C>(&mut self, cookie: C) -> &mut Self
where C: Into<Cookie<'static>>,

Set a cookie.

use coo_kie as cookie;
use ntex::http::{Request, Response};

fn index(req: Request) -> Response {
    Response::Ok()
        .cookie(
            cookie::Cookie::build(("name", "value"))
                .domain("www.rust-lang.org")
                .path("/")
                .secure(true)
                .http_only(true)
        )
        .finish()
}

Remove cookie.

use ntex::http::{Request, Response, HttpMessage};

fn index(req: Request) -> Response {
    let mut builder = Response::Ok();

    if let Some(ref cookie) = req.cookie("name") {
        builder.del_cookie(cookie);
    }

    builder.finish()
}
pub fn extensions(&self) -> Ref<'_, Extensions>

Responses extensions.

pub fn extensions_mut(&self) -> RefMut<'_, Extensions>

Mutable reference to a the response’s extensions.

pub fn body<B: Into<Body>>(&mut self, body: B) -> Response

Set a body and generate Response.

ResponseBuilder can not be used after this call.

pub fn message_body<B>(&mut self, body: B) -> Response<B>

Set a body and generate Response.

ResponseBuilder can not be used after this call.

pub fn streaming<S, E>(&mut self, stream: S) -> Response
where S: Stream<Item = Result<Bytes, E>> + Unpin + 'static, E: Error + 'static,

Set a streaming body and generate Response.

ResponseBuilder can not be used after this call.

pub fn json<T: Serialize>(&mut self, value: &T) -> Response

Set a json body and generate Response.

ResponseBuilder can not be used after this call.

pub fn finish(&mut self) -> Response

Set an empty body and generate Response.

ResponseBuilder can not be used after this call.

pub fn take(&mut self) -> ResponseBuilder

This method construct new ResponseBuilder