pub struct ResourceDef { /* private fields */ }Expand description
ResourceDef describes an entry in resources table
A resource definition can have several path patterns, a path matches the
resource if it matches any of them. The first pattern is the primary one,
it is used by pattern() and for building resource paths.
Implementations
Sourceimpl ResourceDef
impl ResourceDef
Sourcepub fn new<T>(path: T) -> ResourceDefwhere
T: IntoPattern,
pub fn new<T>(path: T) -> ResourceDefwhere
T: IntoPattern,
Parse path patterns and create new ResourceDef instance.
Path segments are separated by /, a leading / is optional. Static
segments could be case insensitive.
Panics if path pattern is malformed.
Sourcepub fn prefix<T>(path: T) -> ResourceDefwhere
T: IntoPattern,
pub fn prefix<T>(path: T) -> ResourceDefwhere
T: IntoPattern,
Parse path patterns and create new prefix ResourceDef instance.
A prefix resource matches paths that start with one of its patterns.
Panics if path pattern is malformed.
Sourcepub fn root_prefix<T>(path: T) -> ResourceDefwhere
T: IntoPattern,
pub fn root_prefix<T>(path: T) -> ResourceDefwhere
T: IntoPattern,
Parse path patterns and create new prefix ResourceDef instance.
Same as prefix(), but inserts / to the start of
the patterns that do not have it.
Panics if path pattern is malformed.
Sourcepub fn id(&self) -> u16
pub fn id(&self) -> u16
Resource id, 0 by default
A matched resource is reported with this id, see
ResourceId.
Sourcepub fn build_path<U, I>(&self, path: &mut String, elements: U) -> bool
pub fn build_path<U, I>(&self, path: &mut String, elements: U) -> bool
Build resource path from elements, using the primary pattern.
Elements are used for dynamic segments in pattern order, an iterator
can be passed by &mut to continue using it afterwards. The path is
appended to path. Returns false if there are not enough elements,
path is left unchanged then.
Sourcepub fn build_path_named<K, V, S>(
&self,
path: &mut String,
elements: &HashMap<K, V, S>,
) -> bool
pub fn build_path_named<K, V, S>( &self, path: &mut String, elements: &HashMap<K, V, S>, ) -> bool
Build resource path from named elements, using the primary pattern.
The path is appended to path. Returns false if an element is
missing, path is left unchanged then.