pub struct RouterEntry<T, U = ()> { /* private fields */ }Expand description
Registered resource, see RouterBuilder.
Holds the resource definition, the value and the optional value passed to
the check function of the recognize_*checked methods.
Implementations
Sourceimpl<T, U> RouterEntry<T, U>
impl<T, U> RouterEntry<T, U>
Sourcepub fn resource(&self) -> &ResourceDef
pub fn resource(&self) -> &ResourceDef
Resource definition
Sourcepub fn resource_mut(&mut self) -> &mut ResourceDef
pub fn resource_mut(&mut self) -> &mut ResourceDef
Mutable reference to the resource definition
Sourcepub fn value_mut(&mut self) -> &mut T
pub fn value_mut(&mut self) -> &mut T
Mutable reference to the value returned for matched resource
Sourcepub fn check_value(&self) -> Option<&U>
pub fn check_value(&self) -> Option<&U>
Value passed to the check function of the recognize_*checked
methods
Sourcepub fn set_check_value<V>(&mut self, value: V) -> &mut RouterEntry<T, U>
pub fn set_check_value<V>(&mut self, value: V) -> &mut RouterEntry<T, U>
Set value passed to the check function of the recognize_*checked
methods
Sourcepub fn set_id(&mut self, id: u16) -> &mut RouterEntry<T, U>
pub fn set_id(&mut self, id: u16) -> &mut RouterEntry<T, U>
Set resource id, see ResourceDef::set_id()
Sourcepub fn set_name<N>(&mut self, name: N) -> &mut RouterEntry<T, U>
pub fn set_name<N>(&mut self, name: N) -> &mut RouterEntry<T, U>
Set resource name, see ResourceDef::set_name()