pub trait IntoPattern {
// Required method
fn patterns(&self) -> Vec<String>;
}Expand description
Helper trait for type that could be converted to path patterns.
Implemented for strings, and for vectors and arrays of strings for resources with several patterns.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".