A runtime implementation that runs everything on the current thread.
Modules
- channel
- A one-shot, futures-aware channel.
- connect
- Tcp connector service
- polling
- rt_
default - rt_
tokio - tokio
- uring
Macros
- syscall
- Helper macro to execute a system call
Structs
- Arbiter
- Arbiters provide an asynchronous execution environment for actors, functions and futures.
- Blocking
Error - An error that may be emitted when all worker threads are busy.
- Blocking
Result - Builder
- Builder struct for a ntex runtime.
- Default
Runtime - Handle
- Handle to the runtime.
- Id
- System id
- Join
Error - Join
Handle - Ping
Record - Runtime
- The async runtime for ntex
- Runtime
Builder - Builder for
Runtime. - System
- System is a runtime manager
- System
Runner - Helper object that runs System’s event loop
- Thread
Pool - A thread pool for executing blocking operations.
Enums
Traits
Functions
- from_
tcp_ stream - Convert std
TcpStreamtoTcpStream - from_
unix_ stream - Convert std
UnixStreamtoUnixStream - get_
item - Get a reference to a type previously inserted on this runtime’s storage
- set_
item - Set item to current runtime’s storage
- spawn
- Spawn a future on the current thread.
- spawn_
blocking - Spawns a blocking task in a new thread, and wait for it.
- task_
callbacks ⚠ - Safety
- task_
opt_ ⚠callbacks - Safety
- tcp_
connect - Opens a TCP connection to a remote host.
- unix_
connect - Opens a unix stream connection.