SharedCfg

Struct SharedCfg 

pub struct SharedCfg(/* private fields */);
An immutable collection of typed configuration values.

Implementations

Source

impl SharedCfg

pub fn new(tag: &'static str) -> SharedCfgBuilder

Starts building a shared configuration with the given tag.

pub fn id(&self) -> usize

Returns the unique identifier of this configuration.

pub fn tag(&self) -> &'static str

Returns the configuration tag.

pub fn service(&self) -> &'static str

Returns the configured service name.

pub fn get<T>(&self) -> Cfg<T>
where T: Configuration,

Returns the configuration value of type T.

Panics

Panics if the shared configuration is still being built.