pub struct ServiceChainFactory<T, Req, C = ()> { /* private fields */ }Expand description
Service factory builder
Implementations
Sourceimpl<T, Req, C> ServiceChainFactory<T, Req, C>where
T: ServiceFactory<Req, C>,
impl<T, Req, C> ServiceChainFactory<T, Req, C>where
T: ServiceFactory<Req, C>,
Sourcepub fn and_then<F, U>(
self,
factory: F,
) -> ServiceChainFactory<AndThenFactory<T, U>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
F: IntoServiceFactory<U, <T as ServiceFactory<Req, C>>::Response, C>,
U: ServiceFactory<<T as ServiceFactory<Req, C>>::Response, C, Error = <T as ServiceFactory<Req, C>>::Error, InitError = <T as ServiceFactory<Req, C>>::InitError>,
pub fn and_then<F, U>(
self,
factory: F,
) -> ServiceChainFactory<AndThenFactory<T, U>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
F: IntoServiceFactory<U, <T as ServiceFactory<Req, C>>::Response, C>,
U: ServiceFactory<<T as ServiceFactory<Req, C>>::Response, C, Error = <T as ServiceFactory<Req, C>>::Error, InitError = <T as ServiceFactory<Req, C>>::InitError>,
Call another service after call to this one has resolved successfully.
Sourcepub fn apply<U>(
self,
tr: U,
) -> ServiceChainFactory<ApplyMiddleware<U, T, C>, Req, C>
pub fn apply<U>( self, tr: U, ) -> ServiceChainFactory<ApplyMiddleware<U, T, C>, Req, C>
Apply middleware to current service factory.
Short version of apply(middleware, chain_factory(...))
Sourcepub fn apply_fn<F, R, In, Out, Err>(
self,
f: F,
) -> ServiceChainFactory<ApplyFactory<T, Req, C, F, R, In, Out, Err>, In, C>where
F: Fn(In, Pipeline<<T as ServiceFactory<Req, C>>::Service>) -> R + Clone,
R: Future<Output = Result<Out, Err>>,
T: ServiceFactory<Req, C>,
Err: From<<T as ServiceFactory<Req, C>>::Error>,
pub fn apply_fn<F, R, In, Out, Err>(
self,
f: F,
) -> ServiceChainFactory<ApplyFactory<T, Req, C, F, R, In, Out, Err>, In, C>where
F: Fn(In, Pipeline<<T as ServiceFactory<Req, C>>::Service>) -> R + Clone,
R: Future<Output = Result<Out, Err>>,
T: ServiceFactory<Req, C>,
Err: From<<T as ServiceFactory<Req, C>>::Error>,
Apply function middleware to current service factory.
Short version of apply_fn_factory(chain_factory(...), fn)
Sourcepub fn then<F, U>(
self,
factory: F,
) -> ServiceChainFactory<ThenFactory<T, U>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
C: Clone,
F: IntoServiceFactory<U, Result<<T as ServiceFactory<Req, C>>::Response, <T as ServiceFactory<Req, C>>::Error>, C>,
U: ServiceFactory<Result<<T as ServiceFactory<Req, C>>::Response, <T as ServiceFactory<Req, C>>::Error>, C, Error = <T as ServiceFactory<Req, C>>::Error, InitError = <T as ServiceFactory<Req, C>>::InitError>,
pub fn then<F, U>(
self,
factory: F,
) -> ServiceChainFactory<ThenFactory<T, U>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
C: Clone,
F: IntoServiceFactory<U, Result<<T as ServiceFactory<Req, C>>::Response, <T as ServiceFactory<Req, C>>::Error>, C>,
U: ServiceFactory<Result<<T as ServiceFactory<Req, C>>::Response, <T as ServiceFactory<Req, C>>::Error>, C, Error = <T as ServiceFactory<Req, C>>::Error, InitError = <T as ServiceFactory<Req, C>>::InitError>,
Create chain factory to chain on a computation for when a call to the
service finished, passing the result of the call to the next
service U.
Note that this function consumes the receiving factory and returns a wrapped version of it.
Sourcepub fn map<F, Res>(
self,
f: F,
) -> ServiceChainFactory<MapFactory<T, F, Req, Res, C>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
F: Fn(<T as ServiceFactory<Req, C>>::Response) -> Res + Clone,
pub fn map<F, Res>(
self,
f: F,
) -> ServiceChainFactory<MapFactory<T, F, Req, Res, C>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
F: Fn(<T as ServiceFactory<Req, C>>::Response) -> Res + Clone,
Map this service’s output to a different type, returning a new service of the resulting type.
Sourcepub fn map_err<F, E>(
self,
f: F,
) -> ServiceChainFactory<MapErrFactory<T, Req, C, F, E>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
F: Fn(<T as ServiceFactory<Req, C>>::Error) -> E + Clone,
pub fn map_err<F, E>(
self,
f: F,
) -> ServiceChainFactory<MapErrFactory<T, Req, C, F, E>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
F: Fn(<T as ServiceFactory<Req, C>>::Error) -> E + Clone,
Map this service’s error to a different error.
Sourcepub fn map_init_err<F, E>(
self,
f: F,
) -> ServiceChainFactory<MapInitErr<T, Req, C, F, E>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
F: Fn(<T as ServiceFactory<Req, C>>::InitError) -> E + Clone,
pub fn map_init_err<F, E>(
self,
f: F,
) -> ServiceChainFactory<MapInitErr<T, Req, C, F, E>, Req, C>where
ServiceChainFactory<T, Req, C>: Sized,
F: Fn(<T as ServiceFactory<Req, C>>::InitError) -> E + Clone,
Map this factory’s init error to a different error, returning a new factory.
Sourcepub async fn pipeline(
&self,
cfg: C,
) -> Result<Pipeline<<T as ServiceFactory<Req, C>>::Service>, <T as ServiceFactory<Req, C>>::InitError>where
ServiceChainFactory<T, Req, C>: Sized,
pub async fn pipeline(
&self,
cfg: C,
) -> Result<Pipeline<<T as ServiceFactory<Req, C>>::Service>, <T as ServiceFactory<Req, C>>::InitError>where
ServiceChainFactory<T, Req, C>: Sized,
Create and return a new service value asynchronously and wrap into a container