Skip to main contentModule util
Source - buffer
- Service that buffers incoming requests.
- either
- Either service allows to use different services for handling request
- inflight
- Service that limits number of in-flight async requests.
- keepalive
- onerequest
- Service that limits number of in-flight async requests to 1.
- retry
- timeout
- Service that applies a timeout to requests.
- variant
- Contains
Variant service and related types and functions.
- BytePage
- BytePages
- ByteString
- An immutable UTF-8 encoded string with
Bytes as a storage. - Bytes
- A reference counted contiguous slice of memory.
- BytesMut
- A unique reference to a contiguous slice of memory.
- Counter
- Simple counter with ability to notify task on reaching specific number
- CounterGuard
- Extensions
- A type map of request extensions.
- Lazy
- Future for the
lazy function. - OnDropFn
- Execute fn during drop
- OnDropFuture
- BytePageSize
- Either
- Combines two different futures, streams, or sinks having the same associated types into a single
type.
- Ready
- A future representing a value that is immediately ready.
- Buf
- Read bytes from a buffer.
- BufMut
- A trait for values that provide sequential write access to bytes.
- OnDropFutureExt
- Trait adds future
on_drop support - Stream
- A stream of values produced asynchronously.
- TryFuture
- A convenience for futures that return
Result values that includes
a variety of adapters tailored to such futures.
- clone_io_error
- dyn_rc_error
- join
- Future for the
join combinator, waiting for two futures to complete. - join_all
- Creates a future which represents a collection of the outputs of the futures
given.
- lazy
- Creates a new future that allows delayed execution of a closure.
- select
- Waits for either one of two differently-typed futures to complete.
- str_rc_error
- stream_recv
- Creates a future that resolves to the next item in the stream.
- BoxFuture
- An owned dynamically typed Future for use in cases where
you can’t statically type your result or need to add some indirection.
- HashMap
- HashSet