pub fn ErrorPreconditionFailed<T, E>(err: T) -> InternalError<T, E>Expand description
Helper function that creates wrapper of any error and generate PRECONDITION FAILED response.
pub fn ErrorPreconditionFailed<T, E>(err: T) -> InternalError<T, E>Helper function that creates wrapper of any error and generate PRECONDITION FAILED response.