pub struct InternalError<T> { /* private fields */ }Expand description
Helper type that can wrap any error and generate custom response.
InternalError renders the wrapped error with a fixed status code, or with a
prepared response, and implements WebResponseError for every error
domain. The Error* helpers in this module, such as ErrorBadRequest,
create InternalError values.
In the following example an io::Error is rendered as 400 Bad Request
instead of the default 500 Internal Server Error.
use ntex::http::StatusCode;
use ntex::web::{self, InternalError};
async fn index() -> Result<&'static str, InternalError<std::io::Error>> {
let err = std::io::Error::other("error");
Err(InternalError::new(err, StatusCode::BAD_REQUEST))
}
let app = web::App::default().route("/", web::get().to(index));Implementations
Sourceimpl<T> InternalError<T>
impl<T> InternalError<T>
Sourcepub fn default(cause: T, status: StatusCode) -> Self
pub fn default(cause: T, status: StatusCode) -> Self
Create InternalError instance
Sourceimpl<T> InternalError<T>
impl<T> InternalError<T>
Sourcepub fn new(cause: T, status: StatusCode) -> Self
pub fn new(cause: T, status: StatusCode) -> Self
Create InternalError instance
Sourcepub fn from_response(cause: T, response: HttpResponse) -> Self
pub fn from_response(cause: T, response: HttpResponse) -> Self
Create InternalError with predefined Response.