pub struct DefaultHeaders { /* private fields */ }Expand description
Middleware for setting default response headers.
This middleware does not set header if response headers already contains it.
use ntex::http;
use ntex::web::{self, middleware, App, HttpResponse};
fn main() {
let app = App::default()
.middleware(middleware::DefaultHeaders::new().header("X-Version", "0.2"))
.service(
web::resource("/test")
.route(web::get().to(async || { HttpResponse::Ok() }))
.route(web::method(http::Method::HEAD).to(async || { HttpResponse::MethodNotAllowed() }))
);
}Implementations
Sourceimpl DefaultHeaders
impl DefaultHeaders
Sourcepub fn new() -> DefaultHeaders
pub fn new() -> DefaultHeaders
Construct DefaultHeaders middleware.
Sourcepub fn header<K, V>(self, key: K, value: V) -> Selfwhere
HeaderName: TryFrom<K>,
<HeaderName as TryFrom<K>>::Error: Into<HttpError>,
HeaderValue: TryFrom<V>,
<HeaderValue as TryFrom<V>>::Error: Into<HttpError>,
pub fn header<K, V>(self, key: K, value: V) -> Selfwhere
HeaderName: TryFrom<K>,
<HeaderName as TryFrom<K>>::Error: Into<HttpError>,
HeaderValue: TryFrom<V>,
<HeaderValue as TryFrom<V>>::Error: Into<HttpError>,
Set a header.
Sourcepub fn content_type(self) -> Self
pub fn content_type(self) -> Self
Set CONTENT-TYPE header if response does not contain this header.
The header is set to application/octet-stream.