pub struct Path<T> { /* private fields */ }Expand description
Extract typed information from the request’s path.
If the path segments cannot be deserialized into T, extraction fails with
PathError, which the default error domain
renders as 404 Not Found.
Path segments are percent-decoded after the path is split on /, so
extracted values can contain any character, including /. For example
/files/..%2F..%2Fetc matches /files/{name} with name set to
../../etc. Validate such values before using them, e.g. as a file system
path.
Example
use ntex::web;
/// extract path info from "/{username}/{count}/index.html" url
/// {username} - deserializes to a String
/// {count} - deserializes to a u32
async fn index(info: web::types::Path<(String, u32)>) -> String {
format!("Welcome {}! {}", info.0, info.1)
}
fn main() {
let app = web::App::default().service(
web::resource("/{username}/{count}/index.html") // <- define path parameters
.route(web::get().to(index)) // <- register handler with `Path` extractor
);
}It is possible to extract path information to a specific type that
implements Deserialize trait from serde.
use std::convert::Infallible;
use ntex::web;
#[derive(serde::Deserialize)]
struct Info {
username: String,
}
/// extract `Info` from a path using serde
async fn index(info: web::types::Path<Info>) -> Result<String, Infallible> {
Ok(format!("Welcome {}!", info.username))
}
fn main() {
let app = web::App::default().service(
web::resource("/{username}/index.html") // <- define path parameters
.route(web::get().to(index)) // <- use handler with `Path` extractor
);
}Implementations
Sourceimpl<T> Path<T>
impl<T> Path<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Deconstruct to an inner value