pub struct Query<T>(pub T);Expand description
Extract typed information from the request’s query.
Note: A query string consists of unordered key=value pairs, therefore it cannot
be decoded into any type which depends upon data ordering e.g. tuples or tuple-structs.
Attempts to do so will fail at runtime.
If the query string cannot be deserialized into T, extraction fails with
QueryPayloadError, which the default
error domain renders as 400 Bad Request.
Example
use ntex::web;
#[derive(Debug, serde::Deserialize)]
pub enum ResponseType {
Token,
Code
}
#[derive(serde::Deserialize)]
pub struct AuthRequest {
id: u64,
response_type: ResponseType,
}
// Use `Query` extractor for query information (and destructure it within the signature).
// If `id` or `response_type` is missing or invalid, extraction fails and the
// handler is not called.
// The correct request for this handler would be `/index.html?id=64&response_type=Code`.
async fn index(web::types::Query(info): web::types::Query<AuthRequest>) -> String {
format!("Authorization request for client with id={} and type={:?}!", info.id, info.response_type)
}
fn main() {
let app = web::App::default().service(
web::resource("/index.html").route(web::get().to(index))); // <- use `Query` extractor
}Tuple Fields
0: TImplementations
Sourceimpl<T> Query<T>
impl<T> Query<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Deconstruct to a inner value
Sourcepub fn from_query(query_str: &str) -> Result<Self, QueryPayloadError>where
T: DeserializeOwned,
pub fn from_query(query_str: &str) -> Result<Self, QueryPayloadError>where
T: DeserializeOwned,
Get query parameters from the path